@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.c,v 1.87 2009/05/20 04:36:51 bowkenken Exp $
+* $Id: amenu.c,v 1.90 2009/06/01 05:05:04 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -54,9 +54,9 @@ static auto_mark_appoint_item_t	clip_board_small_item
 		[AUTO_MARK_APPOINT_ITEM_MAX_N];
 
 static char	msg_ttl_auto_mark[AUTO_MARK_MAX_N]
-		[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+		[MSG_TTL_AUTO_MARK_MAX_BYTE + 1];
 static char	clip_board_ttl
-		[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+		[MSG_TTL_AUTO_MARK_MAX_BYTE + 1];
 
 static long	auto_mark_cur_n;
 static mbr_t	*g_sel_mbr;
@@ -257,7 +257,7 @@ void	init_auto_menu( void )
 	clip_board_small = ls_auto_mark[0][0];
 	str_nz_cpy( clip_board_ttl,
 			msg_ttl_auto_mark[0],
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 }
 
 /***************************************************************
@@ -275,7 +275,7 @@ void	reset_static_auto_menu( void )
 		clip_board_large[i] = dflt_auto_mark_fight;
 	clip_board_small = dflt_auto_mark_fight;
 	str_nz_cpy( clip_board_ttl, "",
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 }
 
 /***************************************************************
@@ -349,7 +349,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_clear;
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_CLEAR,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 		ls_flg_ena_auto_mark[j] = FALSE;
 	}
 
@@ -374,7 +374,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 	}
 	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_FIGHT,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 	ls_flg_ena_auto_mark[j] = TRUE;
 	j++;
 
@@ -397,7 +397,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 	}
 	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_FIGHT_PRIO,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 	ls_flg_ena_auto_mark[j] = TRUE;
 	j++;
 
@@ -418,7 +418,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 	}
 	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_FIGHT_NO_THROW,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 	ls_flg_ena_auto_mark[j] = TRUE;
 	j++;
 
@@ -439,7 +439,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 	}
 	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_FIGHT_NO_THROW_PRIO,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 	ls_flg_ena_auto_mark[j] = TRUE;
 	j++;
 
@@ -449,7 +449,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_all;
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 		ls_flg_ena_auto_mark[j] = TRUE;
 	}
 	j++;
@@ -460,7 +460,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_all_prio;
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL_PRIO,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 		ls_flg_ena_auto_mark[j] = TRUE;
 	}
 	j++;
@@ -471,7 +471,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_clear;
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_RETREAT,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 		ls_flg_ena_auto_mark[j] = TRUE;
 	}
 	j++;
@@ -482,7 +482,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_clear;
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_CLEAR,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 		ls_flg_ena_auto_mark[j] = TRUE;
 	}
 	j++;
@@ -493,7 +493,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_item_all;
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_ITEM_ALL,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 		ls_flg_ena_auto_mark[j] = TRUE;
 	}
 	j++;
@@ -504,7 +504,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_item_own;
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_ITEM_OWN,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 		ls_flg_ena_auto_mark[j] = TRUE;
 	}
 	j++;
@@ -552,7 +552,7 @@ void	ver_up_auto_mark_1_0_4( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_all;
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 	}
 	j++;
 
@@ -569,7 +569,7 @@ void	ver_up_auto_mark_1_0_4( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_all_prio;
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL_PRIO,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 	}
 	j++;
 
@@ -661,13 +661,13 @@ void	ver_up_auto_mark_1_1_3( void )
 void	cv_msg_ttl_auto_mark( char *ttl )
 {
 	const char	old_split[] = " - ";
-	char	work_left[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
-	char	work_right[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+	char	work_left[MSG_TTL_AUTO_MARK_MAX_BYTE + 1];
+	char	work_right[MSG_TTL_AUTO_MARK_MAX_BYTE + 1];
 	char	*p;
 
 	/* ȥ뤫 " - " κ¦Ф */
 
-	str_nz_cpy( work_left, ttl, MSG_TTL_AUTO_MARK_MAX_LEN );
+	str_nz_cpy( work_left, ttl, MSG_TTL_AUTO_MARK_MAX_BYTE );
 	p = strstr( work_left, old_split );
 	if( p != NULL )
 		*p = '\0';
@@ -683,18 +683,19 @@ void	cv_msg_ttl_auto_mark( char *ttl )
 		long	len;
 
 		len = str_len_std( old_split );
-		str_nz_cpy( work_right, &(p[len]), MSG_TTL_AUTO_MARK_MAX_LEN );
+		str_nz_cpy( work_right, &(p[len]),
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 	}
 
 	/* ȥ˽᤹ */
 
 	ttl[0] = '\0';
 	str_max_n_cat( ttl, work_left,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 	str_max_n_cat( ttl, STR_TTL_AUTO_MARK_SPLIT_CODE,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 	str_max_n_cat( ttl, work_right,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 }
 
 /***************************************************************
@@ -724,7 +725,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 {
 	long	left_max_len;
 	menu_t	*p;
-	char	buf[MSG_TTL_AUTO_MARK_MAX_LEN * 3 + 16 + 1];
+	char	buf[MSG_TTL_AUTO_MARK_MAX_BYTE + 1];
 	char	key;
 	long	i, k;
 
@@ -747,7 +748,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 	p[k].accel_key = '\0';
 	p[k].short_key[0] = '\0';
 	str_nz_cpy( p[k].msg, MSG_TTL_MENU_AUTO_MARK,
-			MENU_MSG_MAX_LEN );
+			MENU_MSG_MAX_BYTE );
 	p[k].call_back = NULL;
 	p[k].arg = NULL;
 	p[k].flg = FLG_NULL;
@@ -789,14 +790,14 @@ void	set_menu_auto_mark( menu_t **dflt )
 		kk = k;
 
 		if( ls_flg_ena_auto_mark[i] ){
-			sn_printf( buf, MSG_TTL_AUTO_MARK_MAX_LEN * 3 + 16,
+			sn_printf( buf, MSG_TTL_AUTO_MARK_MAX_BYTE,
 					"%*s%s%s",
 					(int)left_max_len,
 					get_msg_ttl_auto_mark_info( i ),
 					STR_TTL_AUTO_MARK_SPLIT_NAME,
 					get_msg_ttl_auto_mark_hint( i ) );
 		} else {
-			sn_printf( buf, MSG_TTL_AUTO_MARK_MAX_LEN * 3 + 16,
+			sn_printf( buf, MSG_TTL_AUTO_MARK_MAX_BYTE,
 					"%*s%s%s",
 					(int)left_max_len,
 					MSG_MENU_AUTO_MARK_NULL,
@@ -809,7 +810,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		str_nz_cpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 		p[k].accel_key = key;
 		p[k].short_key[0] = '\0';
-		str_nz_cpy( p[k].msg, buf, MENU_MSG_MAX_LEN );
+		str_nz_cpy( p[k].msg, buf, MENU_MSG_MAX_BYTE );
 		p[k].call_back = NULL;
 		p[k].arg = NULL;
 		p[k].flg = FLG_NULL;
@@ -822,7 +823,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].accel_key = 'X';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_EXEC,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_exec;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -834,7 +835,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].accel_key = 'E';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_EDIT,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_edit;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -846,7 +847,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].accel_key = 'N';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_EDIT_NAME,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_edit_name;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -858,7 +859,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].accel_key = 'W';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_COPY,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_copy_large;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -870,7 +871,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].accel_key = 'Y';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_PASTE,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_paste_large;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -882,7 +883,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].accel_key = 'R';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_REMOVE,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_remove;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -894,7 +895,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].accel_key = 'U';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_ARRANGE_UP,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_arrange_up;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -906,7 +907,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].accel_key = 'D';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_ARRANGE_DOWN,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_arrange_down;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -918,7 +919,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].accel_key = 'T';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_ARRANGE_TOP,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_arrange_top;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -930,7 +931,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].accel_key = 'B';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_ARRANGE_BOTTOM,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_arrange_bottom;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -1071,6 +1072,7 @@ bool_t	exec_menu_auto_mark_mnstr( mbr_t *mbr )
 
 	if( mbr == NULL )
 		return FALSE;
+
 	am = &(ls_auto_mark[mbr->ls_mbr_n][auto_mark_cur_n]);
 
 	switch( am->act ){
@@ -1147,12 +1149,14 @@ bool_t	exec_menu_auto_mark_mnstr( mbr_t *mbr )
 
 	/* 򥻥å */
 	set_chr_act( mbr, act_kind, NULL, NULL, 0, 0 );
-
 	/* 󥹥ޡ */
 	mark_mnstr( mbr, mnstr, dist );
 
 	draw_mbr_stat( mbr );
 
+	set_flg_mbr_find_mnstr( TRUE );
+	call_game_sound_play( SOUND_KIND_FIGHT_FIND_MEMBER, 1 );
+
 	return TRUE;
 }
 
@@ -1614,7 +1618,7 @@ char	*cb_menu_auto_mark_edit_init(
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_AUTO_MARK_EDIT,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
@@ -1623,7 +1627,7 @@ char	*cb_menu_auto_mark_edit_init(
 	p = srch_menu( *pp, "target" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_MENU_AUTO_MARK_EDIT_TRGT,
 			get_msg_menu_auto_mark_edit_trgt( g_sel_mbr ) );
 
@@ -1631,7 +1635,7 @@ char	*cb_menu_auto_mark_edit_init(
 	p = srch_menu( *pp, "dist" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_MENU_AUTO_MARK_EDIT_DIST,
 			get_msg_menu_auto_mark_edit_dist( g_sel_mbr ) );
 
@@ -1639,7 +1643,7 @@ char	*cb_menu_auto_mark_edit_init(
 	p = srch_menu( *pp, "action" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_MENU_AUTO_MARK_EDIT_ACT,
 			get_msg_menu_auto_mark_edit_act( g_sel_mbr ) );
 
@@ -1647,7 +1651,7 @@ char	*cb_menu_auto_mark_edit_init(
 	p = srch_menu( *pp, "condition" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_MENU_AUTO_MARK_EDIT_COND,
 			get_msg_menu_auto_mark_edit_cond( g_sel_mbr ) );
 
@@ -1697,7 +1701,7 @@ char	*cb_menu_auto_mark_trgt_init(
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_AUTO_MARK_TRGT,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
@@ -1801,7 +1805,7 @@ char	*cb_menu_auto_mark_dist_init(
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_AUTO_MARK_DIST,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
@@ -1865,7 +1869,7 @@ char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt )
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_AUTO_MARK_ACT,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
@@ -2015,7 +2019,7 @@ char	*cb_menu_auto_mark_cond_init(
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_AUTO_MARK_COND,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
@@ -2116,7 +2120,7 @@ char	*cb_menu_auto_mark_cond_init(
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_AUTO_MARK_COND,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
@@ -2183,7 +2187,7 @@ char	*cb_menu_auto_mark_appoint_item(
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+	sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_AUTO_MARK_APPOINT_ITEM_MJR,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
@@ -2242,7 +2246,7 @@ char	*set_menu_auto_mark_appoint_item(
 	ls[*k].short_key[0] = '\0';
 	ls[*k].n_msg = N_MSG_NULL;
 	str_nz_cpy( ls[*k].msg, get_item_mjr_name( mjr ),
-			MENU_MSG_MAX_LEN );
+			MENU_MSG_MAX_BYTE );
 	ls[*k].call_back = cb_menu_auto_mark_appoint_item_init;
 	ls[*k].arg = (void *)(*apo);
 	ls[*k].flg = FLG_NULL;
@@ -2269,7 +2273,7 @@ char	*set_menu_auto_mark_appoint_item(
 		ls[*k].accel_key = mnr_key;
 		ls[*k].short_key[0] = '\0';
 		ls[*k].n_msg = N_MSG_NULL;
-		str_nz_cpy( ls[*k].msg, name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[*k].msg, name, MENU_MSG_MAX_BYTE );
 		ls[*k].call_back = cb_menu_auto_mark_appoint_item_mnr;
 		ls[*k].arg = (void *)(*apo);
 		ls[*k].flg = FLG_NULL;
@@ -2503,7 +2507,7 @@ char	*cb_menu_auto_mark_copy_large( menu_t **pp, menu_t **dflt )
 
 		str_nz_cpy( clip_board_ttl,
 				msg_ttl_auto_mark[n],
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 	}
 
 	print_msg( FLG_NULL, MSG_MENU_AUTO_MARK_DONE_COPY );
@@ -2535,7 +2539,7 @@ char	*cb_menu_auto_mark_paste_large( menu_t **pp, menu_t **dflt )
 
 		str_nz_cpy( msg_ttl_auto_mark[n],
 				clip_board_ttl,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 	}
 	ls_flg_ena_auto_mark[n] = TRUE;
 
@@ -2610,15 +2614,15 @@ char	*cb_menu_auto_mark_paste_small( menu_t **pp, menu_t **dflt )
 char	*cb_menu_auto_mark_edit_name( menu_t **pp, menu_t **dflt )
 {
 	long	n;
-	static char	info[MSG_TTL_AUTO_MARK_INFO_MAX_LEN + 1];
-	static char	hint[MSG_TTL_AUTO_MARK_HINT_MAX_LEN + 1];
+	static char	info[MSG_TTL_AUTO_MARK_INFO_MAX_BYTE + 1];
+	static char	hint[MSG_TTL_AUTO_MARK_HINT_MAX_BYTE + 1];
 
 	n = (long)((*pp)->arg);
 
 	str_nz_cpy( info, get_msg_ttl_auto_mark_info( n ),
-			MSG_TTL_AUTO_MARK_INFO_MAX_LEN );
+			MSG_TTL_AUTO_MARK_INFO_MAX_BYTE );
 	str_nz_cpy( hint, get_msg_ttl_auto_mark_hint( n ),
-			MSG_TTL_AUTO_MARK_HINT_MAX_LEN );
+			MSG_TTL_AUTO_MARK_HINT_MAX_BYTE );
 
 	wipe_all();
 	gets_auto_mark_info( info );
@@ -2628,13 +2632,13 @@ char	*cb_menu_auto_mark_edit_name( menu_t **pp, menu_t **dflt )
 	msg_ttl_auto_mark[n][0] = '\0';
 	str_max_n_cat( msg_ttl_auto_mark[n],
 			info,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 	str_max_n_cat( msg_ttl_auto_mark[n],
 			STR_TTL_AUTO_MARK_SPLIT_CODE,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 	str_max_n_cat( msg_ttl_auto_mark[n],
 			hint,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 
 	return "/auto mark";
 }
@@ -2799,7 +2803,7 @@ bool_t	arrange_auto_mark_1( long n, long d )
 	auto_mark_t	am;
 	auto_mark_appoint_item_t	item[AUTO_MARK_APPOINT_ITEM_MAX_N];
 	const long	max_item = AUTO_MARK_APPOINT_ITEM_MAX_N;
-	char	buf[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+	char	buf[MSG_TTL_AUTO_MARK_MAX_BYTE + 1];
 
 	if( d == 0 )
 		return FALSE;
@@ -2838,14 +2842,14 @@ bool_t	arrange_auto_mark_1( long n, long d )
 	/**/
 
 	str_nz_cpy( buf, get_msg_ttl_auto_mark_code( n ),
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 
 	str_nz_cpy( get_msg_ttl_auto_mark_code( n ),
 			get_msg_ttl_auto_mark_code( n + d ),
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 
 	str_nz_cpy( get_msg_ttl_auto_mark_code( n + d ), buf,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 
 	/**/
 
@@ -2869,7 +2873,7 @@ bool_t	arrange_auto_mark( long n, long d )
 	auto_mark_appoint_item_t	item[AUTO_MARK_APPOINT_ITEM_MAX_N];
 	auto_mark_appoint_item_t	item_tmp;
 	const long	max_item = AUTO_MARK_APPOINT_ITEM_MAX_N;
-	char	buf[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+	char	buf[MSG_TTL_AUTO_MARK_MAX_BYTE + 1];
 
 	if( d <= -1 )
 		d = -1;
@@ -2953,26 +2957,26 @@ bool_t	arrange_auto_mark( long n, long d )
 	/**/
 
 	str_nz_cpy( buf, get_msg_ttl_auto_mark_code( n ),
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 
 	if( d <= -1 ){
 		for( j = n - 1; j >= 0; j-- ){
 			str_nz_cpy( get_msg_ttl_auto_mark_code( j + 1 ),
 					get_msg_ttl_auto_mark_code( j ),
-					MSG_TTL_AUTO_MARK_MAX_LEN );
+					MSG_TTL_AUTO_MARK_MAX_BYTE );
 		}
 
 		str_nz_cpy( get_msg_ttl_auto_mark_code( 0 ), buf,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 	} else {
 		for( j = n + 1; j < AUTO_MARK_MAX_N; j++ ){
 			str_nz_cpy( get_msg_ttl_auto_mark_code( j - 1 ),
 					get_msg_ttl_auto_mark_code( j ),
-					MSG_TTL_AUTO_MARK_MAX_LEN );
+					MSG_TTL_AUTO_MARK_MAX_BYTE );
 		}
 
 		str_nz_cpy( get_msg_ttl_auto_mark_code( j - 1 ), buf,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 	}
 
 	/**/
@@ -3313,15 +3317,15 @@ char	*get_msg_ttl_auto_mark_code( long n )
 
 char	*get_msg_ttl_auto_mark_name( long n )
 {
-	static char	str[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+	static char	str[MSG_TTL_AUTO_MARK_MAX_BYTE + 1];
 
 	str[0] = '\0';
 	str_max_n_cat( str, get_msg_ttl_auto_mark_info( n ),
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 	str_max_n_cat( str, STR_TTL_AUTO_MARK_SPLIT_NAME,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 	str_max_n_cat( str, get_msg_ttl_auto_mark_hint( n ),
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 
 	return str;
 }
@@ -3334,22 +3338,22 @@ char	*get_msg_ttl_auto_mark_name( long n )
 
 char	*get_msg_ttl_auto_mark_info( long n )
 {
-	static char	str[MSG_TTL_AUTO_MARK_INFO_MAX_LEN + 1];
+	static char	str[MSG_TTL_AUTO_MARK_INFO_MAX_BYTE + 1];
 	char	*ttl, *p;
 
 	ttl = msg_ttl_auto_mark[n];
 
 	p = strstr( ttl, STR_TTL_AUTO_MARK_SPLIT_CODE );
 	if( p == NULL ){
-		str_nz_cpy( str, ttl, MSG_TTL_AUTO_MARK_INFO_MAX_LEN );
+		str_nz_cpy( str, ttl, MSG_TTL_AUTO_MARK_INFO_MAX_BYTE );
 	} else {
 		long	len;
 
 		len = p - ttl;
 		if( len < 0 )
 			len = 0;
-		if( len > MSG_TTL_AUTO_MARK_INFO_MAX_LEN )
-			len = MSG_TTL_AUTO_MARK_INFO_MAX_LEN;
+		if( len > MSG_TTL_AUTO_MARK_INFO_MAX_BYTE )
+			len = MSG_TTL_AUTO_MARK_INFO_MAX_BYTE;
 
 		str_nz_cpy( str, ttl, len );
 	}
@@ -3365,7 +3369,7 @@ char	*get_msg_ttl_auto_mark_info( long n )
 
 char	*get_msg_ttl_auto_mark_hint( long n )
 {
-	static char	str[MSG_TTL_AUTO_MARK_HINT_MAX_LEN + 1];
+	static char	str[MSG_TTL_AUTO_MARK_HINT_MAX_BYTE + 1];
 	char	*ttl, *p;
 
 	ttl = msg_ttl_auto_mark[n];
@@ -3377,7 +3381,7 @@ char	*get_msg_ttl_auto_mark_hint( long n )
 		long	len;
 
 		len = str_len_std( STR_TTL_AUTO_MARK_SPLIT_CODE );
-		str_nz_cpy( str, &(p[len]), MSG_TTL_AUTO_MARK_HINT_MAX_LEN );
+		str_nz_cpy( str, &(p[len]), MSG_TTL_AUTO_MARK_HINT_MAX_BYTE );
 	}
 
 	return str;
