@@ -25,8 +25,11 @@ void	call_gui_input_string_draw(
 	const char *ttl, const char *str, long len
 );
 void	call_gui_input_string_wipe( void );
-void	call_gui_words_draw( const char *str );
-void	call_gui_words_draw_width( const char *str, long w );
+void	call_gui_words_draw( const char *name, const char *str );
+void	call_gui_words_draw_width(
+	const char *name, const char *str,
+	long w
+);
 void	call_gui_words_wipe( void );
 void	call_gui_replay_bgn( void );
 void	call_gui_replay_end( void );
@@ -64,6 +67,8 @@ void	call_pcg_dun_draw_vfx(
 	long scrn_x, long scrn_y,
 	long scrn_w, long scrn_h );
 void	call_pcg_dun_scroll( long map_x, long map_y );
+long	call_pcg_dun_get_crsr_width( bool_t flagSub );
+long	call_pcg_dun_get_crsr_height( bool_t flagSub );
 long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool_t flagPre );
 long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool_t flagPre );
 long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool_t flagPre );
@@ -73,10 +78,11 @@ bool_t	call_pcg_dun_clip_win_x( long mapX );
 bool_t	call_pcg_dun_clip_win_y( long mapY );
 void	call_demo_last_boss_reset( void );
 bool_t	call_demo_last_boss_check_done( void );
-void	call_game_music_play_scene( void );
+void	call_game_music_play_scene( bool_t flg_gui );
 void	call_game_music_play( long kind, long idx );
 void	call_game_music_replay( void );
 void	call_game_sound_play( long kind, long n );
+void	call_game_sound_stop( void );
 long	call_game_joystick_get_joy( void );
 void	call_game_joystick_sel_joy( long n );
 const char	*call_game_joystick_get_name( long n );
