@@ -6,7 +6,16 @@ extern "C" {
 
 void	init_chr( void );
 void	reset_static_chr( void );
+bool_t	chk_flg_run_exec_all_phase( void );
 void	exec_all_phase( void );
+void	clr_chr_find( void );
+void	chk_chr_find( void );
+void	set_flg_mbr_find_mnstr( bool_t flg_find );
+void	set_flg_mnstr_find_mbr( bool_t flg_find );
+void	set_flg_boss_find_mbr( bool_t flg_find );
+bool_t	chk_flg_mbr_find_mnstr( void );
+bool_t	chk_flg_mnstr_find_mbr( void );
+bool_t	chk_flg_boss_find_mbr( void );
 void	last_boss_phase( void );
 void	draw_phase( bool_t flg_first_phase );
 void	move_phase_chr( chr_t *chr );
@@ -72,6 +81,10 @@ bool_t	chr_disarm_trap_abl(
 bool_t	chr_chk_trap( chr_t *chr, trap_t *trap );
 bool_t	chr_open_item( chr_t *chr, item_t *item );
 bool_t	chr_disarm_item( chr_t *chr, item_t *item );
+bool_t	chr_disarm_item_abl(
+	chr_t *chr, item_t *item,
+	abl_kind_t abl_main, abl_kind_t abl_sub
+);
 void	chr_chk_item( chr_t *chr, item_t *item );
 void	chr_srch_obj( chr_t *chr );
 bool_t	chr_srch_obj_sub( chr_t *chr, long x, long y );
@@ -122,6 +135,30 @@ void	exp_chr(
 	bool_t flg_print_exp,
 	bool_t flg_print_lev
 );
+void	exp_mbr(
+	mbr_t *mbr,
+	long exp,
+	bool_t flg_set_max,
+	bool_t flg_print_lev
+);
+void	exp_mbr_skill(
+	mbr_t *mbr,
+	long exp,
+	bool_t flg_set_max,
+	bool_t flg_print_lev
+);
+long	exp_mbr_skill_1(
+	mbr_t *mbr,
+	long exp,
+	skill_kind_t kind,
+	bool_t flg_set_max
+);
+void	exp_mnstr(
+	mnstr_t *mnstr,
+	long exp,
+	bool_t flg_set_max,
+	bool_t flg_print_lev
+);
 void	chk_lev_up( chr_t *chr, bool_t flg_set_max, bool_t flg_draw );
 bool_t	set_lev_up(
 	chr_t *chr,
@@ -152,6 +189,7 @@ long	get_exp( chr_t *chr, abl_kind_t abl );
 long	get_lev( chr_t *chr, abl_kind_t abl );
 long	get_lev_max( chr_t *chr, abl_kind_t abl );
 rate_t	get_resi( chr_t *chr, resi_kind_t resi );
+rate_t	get_resi_max( chr_t *chr, resi_kind_t resi );
 const char	*get_resi_name( resi_kind_t kind );
 bool_t	chk_modified_lev( chr_t *chr, abl_kind_t abl );
 long	calc_abl_to_val( chr_t *chr, abl_kind_t abl );
@@ -183,6 +221,7 @@ rate_t	calc_rate_equip(
 	chr_t *chr, abl_kind_t abl_main, abl_kind_t abl_sub
 );
 bool_t	chk_find_chr( chr_t *p1, chr_t *p2 );
+void	clr_all_chr_flg_blast( void );
 bool_t	is_mbr( chr_t *p );
 bool_t	is_mnstr( chr_t *p );
 bool_t	is_mnstr_or_pet( chr_t *p );
