@@ -53,7 +53,7 @@ ls_msg_t	*get_ls_msg( long idx );
 void	print_str( long scrn_x, long scrn_y, const char *s, ... );
 bool_t	print_vfx( long scrn_x, long scrn_y, const char *s, ... );
 bool_t	print_vfx_cui( long scrn_x, long scrn_y, const char *s, ... );
-void	wipe_vfx( long scrn_x, long scrn_y, long scrn_w, long scrn_h );
+void	wipe_vfx( long map_x, long map_y, long dx, long dy );
 bool_t	set_redraw_every_turn( bool_t flg );
 bool_t	chk_redraw_every_turn( void );
 void	wipe_all( void );
@@ -100,9 +100,9 @@ bool_t	vfx_spell_conflagration_sub( long x, long y, long height );
 void	vfx_spell_earthquake( void );
 void	vfx_spell_thunder( long arw_n, pos_t end[] );
 void	vfx_spell_inundation( void );
-void	vfx_hit( chr_kind_t kind, long x, long y );
-void	vfx_crtcl( chr_kind_t kind, long x, long y );
-void	vfx_ninja_crtcl( chr_kind_t kind, long x, long y );
+void	vfx_hit( chr_t *chr, long x, long y );
+void	vfx_crtcl( chr_t *chr, long x, long y );
+void	vfx_ninja_crtcl( chr_t *chr, long x, long y );
 void	get_vfx_attr( curs_attr_t *attr );
 void	set_vfx_attr( const curs_attr_t *attr );
 void	set_vfx_attr_n( curs_attr_n_t n );
