@@ -103,13 +103,17 @@ bool_t	fx_darkness( long x, long y );
 bool_t	fx_knock( door_t *door );
 bool_t	fx_lock( door_t *door );
 bool_t	fx_disarm_trap( trap_t *trap, chr_t *chr );
+bool_t	fx_teleport_party_charge( void );
 bool_t	fx_teleport_party( void );
+bool_t	teleport_party_charge( void );
+bool_t	chk_teleport_party( void );
 bool_t	teleport_party( void );
 bool_t	fx_teleport( trgt_kind_t trgt_kind, void *p );
 bool_t	teleport_chr( chr_t *chr );
 bool_t	fx_recall( void );
 bool_t	recall( void );
 bool_t	chk_recall( void );
+void	exec_recall( long n );
 bool_t	fx_shelter( long x, long y );
 bool_t	fx_create_food( chr_t *chr );
 bool_t	fx_identify_all_item( mbr_t *mbr );
