@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fx.h,v 1.54 2008/02/14 08:44:16 bowkenken Exp $
+* $Id: fx.h,v 1.58 2009/01/04 00:24:52 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	FX_H
@@ -156,6 +156,45 @@ typedef struct {
 	rate_t	lost_rate;
 } nicotine_t;
 
+/***************************************************************
+* μ
+***************************************************************/
+
+typedef enum {
+	LIQUOR_KIND_RED_WINE,
+	LIQUOR_KIND_WHITE_WINE,
+	LIQUOR_KIND_ROSE_WINE,
+	LIQUOR_KIND_ALE,
+	LIQUOR_KIND_BRANDY,
+	LIQUOR_KIND_RUM,
+	LIQUOR_KIND_MAX_N
+} liquor_kind_t;
+
+/***************************************************************
+* ˾
+***************************************************************/
+
+/* ˾ߤμ */
+typedef enum {
+	WISH_KIND_NULL,
+	WISH_KIND_ARMAGEDDON,
+	WISH_KIND_CURE_HP,
+	WISH_KIND_CURE_MP,
+	WISH_KIND_RESURRECTION,
+	WISH_KIND_ARTIFACT,
+	WISH_KIND_MAX_N,
+} wish_kind_t;
+
+/* μ */
+typedef enum {
+	WISH_LEVEL_NULL,
+	WISH_LEVEL_ARMAGEDDON,
+	WISH_LEVEL_DAEMON,
+	WISH_LEVEL_DJINNI,
+	WISH_LEVEL_GOD,
+	WISH_LEVEL_MAX_N,
+} wish_level_t;
+
 /***************************************************************
 * ե
 ***************************************************************/
@@ -180,20 +219,6 @@ typedef struct fx {
 	abl_kind_t	abl_kind;
 } fx_t;
 
-/***************************************************************
-* μ
-***************************************************************/
-
-typedef enum {
-	LIQUOR_KIND_RED_WINE,
-	LIQUOR_KIND_WHITE_WINE,
-	LIQUOR_KIND_ROSE_WINE,
-	LIQUOR_KIND_ALE,
-	LIQUOR_KIND_BRANDY,
-	LIQUOR_KIND_RUM,
-	LIQUOR_KIND_MAX_N
-} liquor_kind_t;
-
 /***************************************************************
 * 
 ***************************************************************/
