@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile.c,v 1.208 2009/05/24 07:29:25 bowkenken Exp $
+* $Id: gfile.c,v 1.209 2009/05/28 07:29:09 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -1054,6 +1054,48 @@ bool_t	rename_back_up_file( char *fname )
 	return FALSE;
 }
 
+/***************************************************************
+* ǥå饢󥫡Ѵ
+* long idx : ǥå
+* return : 󥫡
+***************************************************************/
+
+square_dir_t	trans_idx_to_square_dir( long idx )
+{
+	long	max_idx;
+
+	max_idx = sizeof( g_square_dir_trans_tab )
+			/ sizeof( g_square_dir_trans_tab[0] );
+
+	if( idx < 0 )
+		return SQUARE_DIR_NORTH;
+	if( idx >= max_idx )
+		return SQUARE_DIR_NORTH;
+
+	return( g_square_dir_trans_tab[idx] );
+}
+
+/***************************************************************
+* 󥫡饤ǥåѴ
+* chr_kind_t k : 󥫡
+* return : ǥå
+***************************************************************/
+
+long	trans_square_dir_to_idx( square_dir_t dir )
+{
+	long	max_idx;
+	long	i;
+
+	max_idx = sizeof( g_square_dir_trans_tab )
+			/ sizeof( g_square_dir_trans_tab[0] );
+
+	for( i = 0; i < max_idx; i++ )
+		if( g_square_dir_trans_tab[i] == dir )
+			return i;
+
+	return 0;
+}
+
 /***************************************************************
 * ǥå饭饯μѴ
 * long idx : ǥå
