@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile.h,v 1.21 2009/05/20 02:36:49 bowkenken Exp $
+* $Id: gfile.h,v 1.23 2009/06/21 12:39:41 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GFILE_H
@@ -184,5 +184,7 @@ EXTERN curs_attr_n_t	g_crnt_attr_n;
 
 EXTERN long	g_game_data_save_n;
 EXTERN replay_kind_t	g_replay_kind_cur;
+EXTERN long	g_load_slot_n;
+EXTERN bool_t	g_flg_exit_shop;
 
 #endif	/* GFILE_H */
