@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.128 2009/05/12 01:30:40 bowkenken Exp $
+* $Id: gmain.c,v 1.131 2009/06/24 02:44:28 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -286,13 +286,20 @@ void	game_main( void )
 
 	if( g_flg_debug ){
 		menu_load_wiz();
+
+		if( !g_flg_gui && g_flg_cui )
+			change_scene( SCENE_N_TOWN );
 	} else {
 		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_1 );
 		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_2 );
 
 		menu_load_start();
 
-		party_exit_bar();
+		if( !g_flg_gui && g_flg_cui )
+			change_scene( SCENE_N_TOWN );
+
+		if( g_load_slot_n != SAVE_N_AUTO )
+			party_exit_bar();
 	}
 
 	while( 1 ){
@@ -709,7 +716,7 @@ void	about_game( bool_t flg_init )
 				LS_STR_COPYRIGHT );
 		str_max_n_cat( str, MSG_ABOUT_GAME, max_len );
 
-		call_gui_words_draw_width( str, 80 );
+		call_gui_words_draw_width( NULL, str, 80 );
 
 		return;
 	}
