@@ -68,6 +68,11 @@ void	move_crsr_abs( long x, long y );
 void	move_crsr_rel( long dx, long dy );
 char	*cb_menu_crsr_quick_move( menu_t **pp, menu_t **dflt );
 void	jump_crsr( long dx, long dy );
+char	*cb_menu_crsr_ind_square( menu_t **pp, menu_t **dflt );
+char	*cb_menu_crsr_ind_square_num( menu_t **pp, menu_t **dflt );
+char	*cb_menu_crsr_ind_square_mbr( menu_t **pp, menu_t **dflt );
+void	menu_crsr_ind_square_set_mbr( long mbr_n );
+char	*cb_menu_crsr_ind_square_party( menu_t **pp, menu_t **dflt );
 char	*cb_menu_crsr_scroll( menu_t **pp, menu_t **dflt );
 void	crsr_scroll( long dx, long dy );
 char	*cb_menu_crsr_move_mbr( menu_t **pp, menu_t **dflt );
@@ -199,6 +204,8 @@ char	*cb_menu_replay_bug_repo( menu_t **pp, menu_t **dflt );
 long	menu_replay_sel_load( void );
 char	*cb_menu_replay_sel_load( menu_t **pp, menu_t **dflt );
 char	*cb_menu_wizard( menu_t **pp, menu_t **dflt );
+char	*cb_menu_wizard_teleport_party( menu_t **pp, menu_t **dflt );
+char	*cb_menu_wizard_recall( menu_t **pp, menu_t **dflt );
 char	*cb_menu_wizard_on_light( menu_t **pp, menu_t **dflt );
 char	*cb_menu_wizard_off_light( menu_t **pp, menu_t **dflt );
 char	*cb_menu_wizard_add_turn_hour( menu_t **pp, menu_t **dflt );
