@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: last-boss.c,v 1.70 2009/05/24 03:05:34 bowkenken Exp $
+* $Id: last-boss.c,v 1.74 2009/06/24 10:44:14 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -1253,6 +1253,8 @@ void	open_last_boss_gate( void )
 	dun_t	*dun;
 	long	i;
 
+	call_game_sound_play( SOUND_KIND_EVENT_GATE, 1 );
+
 	dun = get_dun();
 	for( i = 0; i < dun->door_n; i++ ){
 		dun->door[i].flg &= ~(FLG_DOOR_JAMMED | FLG_DOOR_BROKEN);
@@ -1334,6 +1336,8 @@ void	draw_xx_enter( void )
 	bgn_time = time( NULL );
 	flg_end = FALSE;
 
+	call_game_sound_play( SOUND_KIND_EVENT_EARTHQUAKE, 20 );
+
 	for( i = 0; i < LOOP_MAX_1000; i++ ){
 		/*  */
 
@@ -1471,6 +1475,8 @@ void	draw_xx_enter( void )
 		}
 	}
 
+	call_game_sound_stop();
+
 	/* ̤ΰ֤򸵤᤹ */
 
 	draw->x = pre_draw.x;
@@ -2557,6 +2563,40 @@ void	act_mnstr_xx( mnstr_t *p )
 	redraw_map();
 }
 
+/***************************************************************
+* XX Υθ̲
+* xx_act_kind_t kind : μ
+***************************************************************/
+
+void	play_sound_xx( xx_act_kind_t kind )
+{
+	sound_kind_t	sk;
+
+	sk = SOUND_KIND_NULL;
+
+	switch( kind ){
+	case XX_ACT_KIND_NULL:
+	case XX_ACT_KIND_MAX_N:
+		break;
+	case XX_ACT_KIND_HEAT:
+	case XX_ACT_KIND_COLD:
+	case XX_ACT_KIND_MIND:
+	case XX_ACT_KIND_ACID:
+		sk = SOUND_KIND_FIGHT_ATTACK_LAST_BOSS_ATTACK;
+		break;
+	case XX_ACT_KIND_PARALYZE:
+	case XX_ACT_KIND_POISON:
+	case XX_ACT_KIND_SLEEP:
+		sk = SOUND_KIND_FIGHT_ATTACK_LAST_BOSS_WEAKEN;
+		break;
+	case XX_ACT_KIND_SLAP:
+		sk = SOUND_KIND_FIGHT_ATTACK_LAST_BOSS_SLAP;
+		break;
+	}
+
+	call_game_sound_play( sk, 1 );
+}
+
 /***************************************************************
 * XX μʸ
 * mnstr_t *p : XX Υ饯ǡ
@@ -2608,7 +2648,9 @@ void	xx_act_heat( mnstr_t *p )
 {
 	set_open_xx_jaw( TRUE );
 
+	play_sound_xx( XX_ACT_KIND_HEAT );
 	xx_act_heat_draw( p );
+	play_sound_xx( XX_ACT_KIND_HEAT );
 	xx_act_heat_draw( p );
 
 	redraw_map();
@@ -2649,7 +2691,7 @@ void	xx_act_heat_draw( mnstr_t *p )
 		if( xx_heat.head_y > end_y )
 			break;
 
-		if( g_flg_cui && !g_flg_gui )
+		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
 			redraw_map();
 
 		if( (xx_heat.head_y % XX_HEAT_DY) == 0 ){
@@ -2695,6 +2737,7 @@ void	xx_act_heat_draw( mnstr_t *p )
 
 void	xx_act_cold( mnstr_t *p )
 {
+	play_sound_xx( XX_ACT_KIND_COLD );
 	xx_act_cold_draw( p );
 
 	redraw_map();
@@ -2761,7 +2804,7 @@ void	xx_act_cold_draw( mnstr_t *p )
 	for( i = 0; i < LOOP_MAX_100; i++ ){
 		bool_t	flg_next;
 
-		if( g_flg_cui && !g_flg_gui )
+		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
 			redraw_map();
 
 		flg_next = TRUE;
@@ -2803,7 +2846,7 @@ void	xx_act_cold_draw( mnstr_t *p )
 	/* 졼ȯͤ */
 
 	for( i = 0; i < LOOP_MAX_100; i++ ){
-		if( g_flg_cui && !g_flg_gui )
+		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
 			redraw_map();
 
 		for( n = 0; n < MBR_MAX_N; n++ ){
@@ -2822,7 +2865,16 @@ void	xx_act_cold_draw( mnstr_t *p )
 				x += (xx_laser_dxy[n].x * j);
 				y += (xx_laser_dxy[n].y * j);
 
-				print_vfx_cui( x, y, MSG_S, xx_laser[n] );
+				if( g_flg_text_mode )
+					curs_attrset_n( CURS_ATTR_N_COLD );
+
+				if( g_flg_gui && g_flg_text_mode ){
+					print_vfx( x, y, MSG_S,
+							xx_laser[n] );
+				} else {
+					print_vfx_cui( x, y, MSG_S,
+							xx_laser[n] );
+				}
 			}
 			curs_attrset_dflt();
 
@@ -2864,6 +2916,7 @@ pos_t	*get_xx_laser_dxy( void )
 
 void	xx_act_mind( mnstr_t *p )
 {
+	play_sound_xx( XX_ACT_KIND_MIND );
 	xx_act_mind_draw( p );
 
 	redraw_map();
@@ -2904,7 +2957,7 @@ void	xx_act_mind_draw( mnstr_t *p )
 	/*  */
 
 	for( i = 0; i < LOOP_MAX_100; i++ ){
-		if( g_flg_cui && !g_flg_gui )
+		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
 			redraw_map();
 
 		/* ư */
@@ -3027,7 +3080,13 @@ static void xx_mind_draw( xx_mind_t *xx_mind )
 			else
 				str = xx_refract_image;
 
-			print_vfx_cui( x, y, MSG_S, str );
+			if( g_flg_text_mode )
+				curs_attrset_n( CURS_ATTR_N_MIND );
+
+			if( g_flg_gui && g_flg_text_mode )
+				print_vfx( x, y, MSG_S, str );
+			else
+				print_vfx_cui( x, y, MSG_S, str );
 		}
 	}
 	curs_attrset_dflt();
@@ -3042,7 +3101,9 @@ void	xx_act_acid( mnstr_t *p )
 {
 	set_open_xx_jaw( TRUE );
 
+	play_sound_xx( XX_ACT_KIND_ACID );
 	xx_act_acid_draw( p );
+	play_sound_xx( XX_ACT_KIND_ACID );
 	xx_act_acid_draw( p );
 
 	redraw_map();
@@ -3111,7 +3172,7 @@ void	xx_act_acid_draw( mnstr_t *p )
 	/*  */
 
 	for( i = 0; i < LOOP_MAX_100; i++ ){
-		if( g_flg_cui && !g_flg_gui )
+		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
 			redraw_map();
 
 		if( xx_acid_chk_end( &xx_acid ) )
@@ -3291,7 +3352,13 @@ static void xx_acid_draw( xx_acid_t *xx_acid )
 			else
 				str = xx_homing_image;
 
-			print_vfx_cui( x, y, MSG_S, str );
+			if( g_flg_text_mode )
+				curs_attrset_n( CURS_ATTR_N_ACID );
+
+			if( g_flg_gui && g_flg_text_mode )
+				print_vfx( x, y, MSG_S, str );
+			else
+				print_vfx_cui( x, y, MSG_S, str );
 		}
 	}
 	curs_attrset_dflt();
@@ -3306,6 +3373,7 @@ void	xx_act_rotation( mnstr_t *p )
 {
 	set_open_xx_jaw( TRUE );
 
+	play_sound_xx( XX_ACT_KIND_PARALYZE );
 	xx_act_rotation_draw( p );
 
 	redraw_map();
@@ -3374,7 +3442,7 @@ void	xx_act_rotation_draw( mnstr_t *p )
 			}
 		}
 
-		if( g_flg_cui && !g_flg_gui )
+		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
 			redraw_map();
 
 		curs_attrset_n( CURS_ATTR_N_COLD );
@@ -3388,7 +3456,17 @@ void	xx_act_rotation_draw( mnstr_t *p )
 				x -= draw->x;
 				y -= draw->y;
 				x *= 2;
-				print_vfx_cui( x, y, MSG_S, xx_rotation_str );
+
+				if( g_flg_text_mode )
+					curs_attrset_n( CURS_ATTR_N_COLD );
+
+				if( g_flg_gui && g_flg_text_mode ){
+					print_vfx( x, y, MSG_S,
+							xx_rotation_str );
+				} else {
+					print_vfx_cui( x, y, MSG_S,
+							xx_rotation_str );
+				}
 			}
 		}
 		curs_attrset_dflt();
@@ -3469,6 +3547,7 @@ void	xx_act_whirl( mnstr_t *p )
 {
 	set_open_xx_jaw( TRUE );
 
+	play_sound_xx( XX_ACT_KIND_POISON );
 	xx_act_whirl_draw( p );
 
 	redraw_map();
@@ -3529,7 +3608,7 @@ void	xx_act_whirl_draw( mnstr_t *p )
 			xx_whirl.y[n] = y;
 		}
 
-		if( g_flg_cui && !g_flg_gui )
+		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
 			redraw_map();
 
 		curs_attrset_n( CURS_ATTR_N_HEAT );
@@ -3543,7 +3622,13 @@ void	xx_act_whirl_draw( mnstr_t *p )
 			y -= draw->y;
 			x *= 2;
 
-			print_vfx_cui( x, y, MSG_S, xx_whirl_str );
+			if( g_flg_text_mode )
+				curs_attrset_n( CURS_ATTR_N_HEAT );
+
+			if( g_flg_gui && g_flg_text_mode )
+				print_vfx( x, y, MSG_S, xx_whirl_str );
+			else
+				print_vfx_cui( x, y, MSG_S, xx_whirl_str );
 		}
 		curs_attrset_dflt();
 
@@ -3599,6 +3684,7 @@ void	xx_act_whirl_draw( mnstr_t *p )
 
 void	xx_act_fan( mnstr_t *p )
 {
+	play_sound_xx( XX_ACT_KIND_SLEEP );
 	xx_act_fan_draw( p );
 
 	redraw_map();
@@ -3662,7 +3748,7 @@ void	xx_act_fan_draw( mnstr_t *p )
 			}
 		}
 
-		if( g_flg_cui && !g_flg_gui )
+		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
 			redraw_map();
 
 		curs_attrset_n( CURS_ATTR_N_MIND );
@@ -3677,7 +3763,16 @@ void	xx_act_fan_draw( mnstr_t *p )
 				y -= draw->y;
 				x *= 2;
 
-				print_vfx_cui( x, y, MSG_S, xx_fan_str );
+				if( g_flg_text_mode )
+					curs_attrset_n( CURS_ATTR_N_MIND );
+
+				if( g_flg_gui && g_flg_text_mode ){
+					print_vfx( x, y, MSG_S,
+							xx_fan_str );
+				} else {
+					print_vfx_cui( x, y, MSG_S,
+							xx_fan_str );
+				}
 			}
 		}
 		curs_attrset_dflt();
@@ -3751,7 +3846,9 @@ void	xx_act_fan_draw( mnstr_t *p )
 
 void	xx_act_slap( mnstr_t *p )
 {
+	play_sound_xx( XX_ACT_KIND_SLAP );
 	xx_act_slap_draw( p );
+	play_sound_xx( XX_ACT_KIND_SLAP );
 	xx_act_slap_draw( p );
 
 	redraw_map();
