@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu-tab.h,v 1.23 2009/01/04 00:24:52 bowkenken Exp $
+* $Id: menu-tab.h,v 1.24 2009/06/01 05:05:04 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MENU_TAB_H
@@ -77,7 +77,7 @@ typedef struct menu_t {
 
 	/* ̾ */
 	n_msg_t	n_msg;
-	char	msg[MENU_MSG_MAX_LEN + 1];
+	char	msg[MENU_MSG_MAX_BYTE + 1];
 
 	/* 롦Хåؿ */
 	menu_call_back_t	call_back;
