@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu.c,v 1.209 2008/09/07 11:31:27 bowkenken Exp $
+* $Id: menu.c,v 1.216 2009/06/01 05:05:04 bowkenken Exp $
 ***************************************************************/
 
 #define	MENU_C
@@ -261,7 +261,7 @@ void	init_ls_menu_func( void )
 	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
-	str_nz_cpy( ls[k].msg, MSG_MENU_FUNC, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_MENU_FUNC, MENU_MSG_MAX_BYTE );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -294,7 +294,7 @@ void	init_ls_menu_func( void )
 		str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
-		sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+		sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
 				MSG_MENU_FUNC_KEY, fn );
 		ls[k].call_back = NULL;
 		ls[k].arg = NULL;
@@ -306,7 +306,7 @@ void	init_ls_menu_func( void )
 		str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
-		sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+		sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
 				MSG_MENU_FUNC_KEY, fn );
 		ls[k].call_back = NULL;
 		ls[k].arg = NULL;
@@ -325,7 +325,7 @@ void	init_ls_menu_func( void )
 					"%s &%02ld",
 					g_ls_func_short_key[i].key, fn );
 		}
-		str_nz_cpy( ls[k].msg, MSG_MENU_FUNC_EXEC, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, MSG_MENU_FUNC_EXEC, MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_func_exec;
 		ls[k].arg = (void *)fn;
 		ls[k].flg = FLG_NULL;
@@ -336,7 +336,7 @@ void	init_ls_menu_func( void )
 		str_nz_cpy( ls[k].kind, "<OpenWinItem>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = 'E';
 		ls[k].short_key[0] = '\0';
-		str_nz_cpy( ls[k].msg, MSG_MENU_FUNC_EDIT, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, MSG_MENU_FUNC_EDIT, MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_func_edit;
 		ls[k].arg = (void *)fn;
 		ls[k].flg = FLG_NULL;
@@ -348,7 +348,7 @@ void	init_ls_menu_func( void )
 		ls[k].accel_key = 'M';
 		ls[k].short_key[0] = '\0';
 		str_nz_cpy( ls[k].msg, MSG_MENU_FUNC_SET_REG_MACRO,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_func_set_reg_macro;
 		ls[k].arg = (void *)fn;
 		ls[k].flg = FLG_NULL;
@@ -614,6 +614,16 @@ bool_t	set_menu_radio_item( menu_t *ls, menu_t *p )
 /**/
 
 ask_t	exec_menu_ask( char *ttl, ask_t dflt, bool_t can_cancel )
+{
+	if( ttl != NULL )
+		print_msg( FLG_NULL, MSG_S, ttl );
+
+	return exec_menu_ask_no_msg( ttl, dflt, can_cancel );
+}
+
+/**/
+
+ask_t	exec_menu_ask_no_msg( char *ttl, ask_t dflt, bool_t can_cancel )
 {
 	menu_t	*p;
 	char	*str_goto;
@@ -627,7 +637,7 @@ ask_t	exec_menu_ask( char *ttl, ask_t dflt, bool_t can_cancel )
 	if( ttl == NULL )
 		p->msg[0] = '\0';
 	else
-		str_nz_cpy( p->msg, ttl, MENU_MSG_MAX_LEN );
+		str_nz_cpy( p->msg, ttl, MENU_MSG_MAX_BYTE );
 
 	while( 1 ){
 		str_goto = exec_menu( ls_menu_ask, NULL, NULL );
@@ -689,7 +699,7 @@ char	*cb_menu_ask_no( menu_t **pp, menu_t **dflt )
 char	*exec_menu_sel_num( long *p, long min, long max )
 {
 	long	n;
-	long	gui_n;
+	volatile long	gui_n;
 	long	figure;
 	long	sel_n;
 	char	num[FIGURE_MAX_N];
@@ -715,6 +725,7 @@ char	*exec_menu_sel_num( long *p, long min, long max )
 	sel_n = 1 + figure + MENU_NUM_OK;
 	while( 1 ){
 		long	d;
+		bool_t	flg_d;
 		bool_t	flg_ret;
 		char	key;
 
@@ -725,7 +736,7 @@ char	*exec_menu_sel_num( long *p, long min, long max )
 		key = get_key_buf_char();
 		if( key == '\0' ){
 			if( g_flg_gui ){
-				call_gui_num_draw( &gui_n, min, max,
+				call_gui_num_draw( &n, min, max,
 						figure );
 			}
 
@@ -733,6 +744,7 @@ char	*exec_menu_sel_num( long *p, long min, long max )
 		}
 
 		d = 0;
+		flg_d = FALSE;
 		flg_ret = FALSE;
 
 		switch( key ){
@@ -751,11 +763,17 @@ char	*exec_menu_sel_num( long *p, long min, long max )
 				d = +1;
 			}
 			break;
+		case CASE_EXEC:
+			d = +-0;
+			flg_d = TRUE;
+			break;
 		case CASE_CRSR_UP:
 			d = +1;
+			flg_d = TRUE;
 			break;
 		case CASE_CRSR_DOWN:
 			d = -1;
+			flg_d = TRUE;
 			break;
 		case CASE_CRSR_LEFT:
 			sel_n--;
@@ -769,7 +787,6 @@ char	*exec_menu_sel_num( long *p, long min, long max )
 				sel_n = 0;
 			break;
 		case '|':
-			n = gui_n;
 			break;
 		case KEY_MENU_NUM_OK:
 			sel_n = 1 + figure + MENU_NUM_OK;
@@ -792,7 +809,7 @@ char	*exec_menu_sel_num( long *p, long min, long max )
 			break;
 		}
 
-		if( (d != 0) || flg_ret ){
+		if( flg_d || flg_ret ){
 			if( sel_n == 1 + figure + MENU_NUM_OK ){
 				if( flg_ret ){
 					if( n < min ){
@@ -825,7 +842,11 @@ char	*exec_menu_sel_num( long *p, long min, long max )
 			} else {
 				long	m;
 
-				m = num[sel_n] - '0' + d;
+				if( d == +-0 )
+					m = 0;
+				else
+					m = num[sel_n] - '0' + d;
+
 				if( m > 9 )
 					m = 0;
 				if( m < 0 )
@@ -951,12 +972,18 @@ menu_t	*sel_menu( menu_t *p, menu_t *dflt )
 			if( i >= max_n )
 				break;
 
+			call_game_sound_play(
+					SOUND_KIND_MENU_SELECT,
+					1 );
 			sel_n = i;
 			sel_menu_clr( &data );
 			return( data.ls[sel_n] );
 		case ' ':
 			if( g_flg_space_select ){
 				/* ܤ */
+				call_game_sound_play(
+						SOUND_KIND_MENU_SELECT,
+						1 );
 				sel_menu_clr( &data );
 				return( data.ls[sel_n] );
 			} else {
@@ -965,14 +992,24 @@ menu_t	*sel_menu( menu_t *p, menu_t *dflt )
 		case CASE_ENTER:
 			if( g_flg_space_select ){
 				/* ˥塼Ĥ */
+				call_game_sound_play(
+						SOUND_KIND_MENU_CANCEL,
+						1 );
 				sel_menu_clr( &data );
 				return NULL;
 			} else {
 				/* ܤ */
+				call_game_sound_play(
+						SOUND_KIND_MENU_SELECT,
+						1 );
 				sel_menu_clr( &data );
 				return( data.ls[sel_n] );
 			}
 		case CASE_CANCEL:
+			/* ˥塼Ĥ */
+			call_game_sound_play(
+					SOUND_KIND_MENU_CANCEL,
+					1 );
 			sel_menu_clr( &data );
 			return NULL;
 		case CASE_CRSR_UP:
@@ -1010,8 +1047,22 @@ menu_t	*sel_menu( menu_t *p, menu_t *dflt )
 			dx = (page_max_n - 1) - page_sel_n;
 			break;
 		case '/':
+			call_game_sound_play(
+					SOUND_KIND_MENU_CANCEL,
+					1 );
 			return &dummy_menu_close_menu;
 			break;
+		case 'g':
+			call_game_sound_play(
+					SOUND_KIND_MENU_SELECT,
+					1 );
+
+			exec_back_log();
+
+			call_game_sound_play(
+					SOUND_KIND_MENU_CANCEL,
+					1 );
+			break;
 		}
 
 		if( dy != +-0 ){
@@ -1079,7 +1130,7 @@ long	set_ls_menu(
 
 		if( tmp_p->msg[0] == '\0' )
 			str_nz_cpy( tmp_p->msg, MSG( tmp_p->n_msg ),
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 
 		if( page_n == page_sel_n ){
 			if( strcmp( tmp_p->kind, "<Title>" ) == 0 ){
