@@ -45,13 +45,17 @@ void	set_flg_work_find_mbr( mnstr_t *p, bool_t flg );
 void	chk_boss_find_mbr( mnstr_t *p );
 void	chk_trap_all_mnstr( void );
 void	die_mnstr_drop_item( mnstr_t *p );
-void	die_mnstr( mnstr_t *p );
+void	die_mnstr( mnstr_t *p, bool_t flg_msg );
 bool_t	chk_die_boss( mnstr_t *p );
+bool_t	is_boss( mnstr_t *p );
+bool_t	is_last_boss( mnstr_t *p );
+bool_t	is_xx( mnstr_t *p );
 void	die_boss( mnstr_t *m );
 void	garbage_collection_all_mnstr( void );
 void	mnstr_drop_gold( mnstr_t *p );
 void	mnstr_drop_bone( mnstr_t *p );
 void	mnstr_drop_item( mnstr_t *p );
+void	mnstr_drop_key_item( mnstr_t *p );
 void	set_find_all_mnstr( void );
 void	print_ls_mnstr( void );
 mnstr_kind_t	get_npc_kind_randm( void );
@@ -68,12 +72,6 @@ mnstr_tab_t	*get_towner_tab_rand( void );
 long	get_mnstr_lev_tab_max( void );
 mnstr_lev_tab_t	*get_mnstr_lev_tab( mnstr_kind_t mnstr_kind, long dun_lev );
 void	ins_ls_mnstr( mnstr_t *ls, mnstr_t *p );
-void	exp_chr_mnstr(
-	chr_t *chr,
-	long exp,
-	bool_t flg_set_max,
-	bool_t flg_print_lev
-);
 long	calc_mnstr_exp( mnstr_t *p, long dun_lev );
 long	calc_mnstr_exp_sub( mnstr_t *p, long dun_lev );
 long	calc_mnstr_abl_lev( long dun_lev, abl_kind_t k, mnstr_tab_t *tab );
