@@ -6,6 +6,7 @@ extern "C" {
 
 void	init_pet( void );
 void	reset_static_pet( void );
+void	init_pet_dflt( void );
 void	init_pet_debug( void );
 pet_t	*make_pet( long dun_lev, pet_kind_t pet_kind, chr_t *owner );
 pet_t	*make_pet_alloc( pet_t *p, long dun_lev, pet_kind_t pet_kind );
@@ -31,7 +32,7 @@ bool_t	chk_can_not_join_pet( pet_t *p );
 bool_t	join_pet( pet_t *p );
 bool_t	not_join_pet( pet_t *p );
 void	garbage_collection_all_pet( void );
-void	die_pet( pet_t *p );
+void	die_pet( pet_t *p, bool_t flg_msg );
 void	remove_pet( pet_t *p );
 bool_t	dismissal( pet_t *p );
 
