@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: scene.c,v 1.16 2009/01/04 00:24:52 bowkenken Exp $
+* $Id: scene.c,v 1.17 2009/06/03 19:25:12 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -264,9 +264,34 @@ bool_t	scene_srch_battle( void )
 
 /***************************************************************
 * ڤؤ
+* scene_n_t n : 
+* return : ڤ괹줿
 ***************************************************************/
 
 scene_n_t	change_scene( scene_n_t n )
+{
+	return change_scene_sub( n, FALSE );
+}
+
+/***************************************************************
+* ڤؤ (GUI)
+* scene_n_t n : 
+* return : ڤ괹줿
+***************************************************************/
+
+scene_n_t	change_scene_gui( scene_n_t n )
+{
+	return change_scene_sub( n, TRUE );
+}
+
+/***************************************************************
+* ڤؤ
+* scene_n_t n : 
+* bool_t flg_gui : GUI ƤФ줿?
+* return : ڤ괹줿
+***************************************************************/
+
+scene_n_t	change_scene_sub( scene_n_t n, bool_t flg_gui )
 {
 	if( n <= SCENE_N_NULL )
 		return SCENE_N_NULL;
@@ -275,13 +300,14 @@ scene_n_t	change_scene( scene_n_t n )
 
 	scene_n = n;
 
-	call_game_music_play_scene();
+	call_game_music_play_scene( flg_gui );
 
 	return scene_n;
 }
 
 /***************************************************************
 * ֤
+* return : ֹ
 ***************************************************************/
 
 scene_n_t	get_scene( void )
@@ -291,9 +317,34 @@ scene_n_t	get_scene( void )
 
 /***************************************************************
 * 饹ܥΥڤؤ
+* last_scene_n_t n : 饹ܥΥ
+* return : ڤ괹줿饹ܥΥ
 ***************************************************************/
 
 last_scene_n_t	change_last_scene( last_scene_n_t n )
+{
+	return change_last_scene_sub( n, FALSE );
+}
+
+/***************************************************************
+* 饹ܥΥڤؤ (GUI)
+* last_scene_n_t n : 饹ܥΥ
+* return : ڤ괹줿饹ܥΥ
+***************************************************************/
+
+last_scene_n_t	change_last_scene_gui( last_scene_n_t n )
+{
+	return change_last_scene_sub( n, TRUE );
+}
+
+/***************************************************************
+* 饹ܥΥڤؤ
+* last_scene_n_t n : 饹ܥΥ
+* bool_t flg_gui : GUI ƤФ줿?
+* return : ڤ괹줿饹ܥΥ
+***************************************************************/
+
+last_scene_n_t	change_last_scene_sub( last_scene_n_t n, bool_t flg_gui )
 {
 	if( n < LAST_SCENE_N_NULL )
 		return LAST_SCENE_N_NULL;
@@ -304,7 +355,7 @@ last_scene_n_t	change_last_scene( last_scene_n_t n )
 	last_scene_n = n;
 
 	call_demo_last_boss_reset();
-	call_game_music_play_scene();
+	call_game_music_play_scene( flg_gui );
 
 	return last_scene_n;
 }
