@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.187 2009/02/24 09:24:27 bowkenken Exp $
+* $Id: spell.c,v 1.195 2009/06/23 03:23:26 bowkenken Exp $
 ***************************************************************/
 
 #define	SPELL_C
@@ -138,7 +138,7 @@ void	init_spell( void )
 
 		min_len = get_pading_len( MSG( ls[i].n_msg ), max_len );
 
-		sn_printf( ls[i].msg, MENU_MSG_MAX_LEN,
+		sn_printf( ls[i].msg, MENU_MSG_MAX_BYTE,
 				MSG_MENU_SPELL_LS,
 				min_len,
 				MSG( ls[i].n_msg ),
@@ -191,28 +191,34 @@ void	init_spell_debug( void )
 
 	m = LS_MBR_N_CECILE;
 	for( k = SPELL_KIND_PRI_MIN_N + 1; k < SPELL_KIND_PRI_MAX_N; k++ ){
+#if	0
 		if( k == SPELL_KIND_CURE_PARALYZE )
 			continue;
 		if( k == SPELL_KIND_CURE_BLINDNESS )
 			continue;
+#endif
 
 		cast_tab[m][k].flg_cast = TRUE;
 	}
 
 	m = LS_MBR_N_HALLE;
 	for( k = SPELL_KIND_BAR_MIN_N + 1; k < SPELL_KIND_BAR_MAX_N; k++ ){
+#if	0
 		if( k == SPELL_KIND_SONG_DULLNESS )
 			continue;
+#endif
 
 		cast_tab[m][k].flg_cast = TRUE;
 	}
 
 	m = LS_MBR_N_BEAUT;
 	for( k = SPELL_KIND_NULL + 1; k < SPELL_KIND_MAX_N; k++ ){
+#if	0
 		if( k == SPELL_KIND_CREATE_FOOD )
 			continue;
 		if( k == SPELL_KIND_CREATE_UNDEAD )
 			continue;
+#endif
 
 		cast_tab[m][k].flg_cast = TRUE;
 	}
@@ -552,7 +558,8 @@ char	*cb_menu_spell( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_spell_extent( menu_t **pp, menu_t **dflt )
 {
-	char	*str_goto;
+	extent_kind_t	ex;
+	bool_t	flg_trgt;
 
 	if( g_sel_mbr == NULL )
 		return STR_MENU_ERR;
@@ -561,7 +568,26 @@ char	*cb_menu_spell_extent( menu_t **pp, menu_t **dflt )
 
 	g_dflt_spell_extent[g_sel_mbr->ls_mbr_n][g_sel_spell_abl] = *pp;
 
-	if( g_sel_spell->flg_trgt ){
+	ex = (extent_kind_t)(long)((*pp)->arg);
+
+	flg_trgt = FALSE;
+	if( g_sel_spell->flg_trgt )
+		flg_trgt = TRUE;
+	do {
+		if( g_sel_spell->kind < SPELL_KIND_BAR_MIN_N )
+			break;
+		if( g_sel_spell->kind > SPELL_KIND_BAR_MAX_N )
+			break;
+		if( ex != EXTENT_KIND_NORMAL )
+			break;
+
+		flg_trgt = FALSE;
+		break;
+	} while( 0 );
+
+	if( flg_trgt ){
+		char	*str_goto;
+
 		str_goto = menu_spell_trgt( g_sel_mbr );
 		if( str_goto != NULL )
 			return str_goto;
@@ -569,9 +595,7 @@ char	*cb_menu_spell_extent( menu_t **pp, menu_t **dflt )
 
 	/*  */
 
-	set_chr_act( g_sel_mbr, ACT_KIND_SPELL,
-			g_sel_spell, NULL,
-			(extent_kind_t)(long)((*pp)->arg), 0 );
+	set_chr_act( g_sel_mbr, ACT_KIND_SPELL, g_sel_spell, NULL, ex, 0 );
 
 	return NULL;
 }
@@ -826,6 +850,8 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 	} while( 0 );
 
 	if( flg_msg ){
+		play_sound_spell( chr, tab->kind );
+
 		if( fmt == NULL ){
 			print_msg( FLG_NULL, MSG_SPELL,
 					chr->name, tab->name );
@@ -843,6 +869,10 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 	case EXTENT_KIND_MAX_N:
 		break;
 	case EXTENT_KIND_NORMAL:
+		if( (SPELL_KIND_BAR_MIN_N <= tab->kind)
+				&& (tab->kind <= SPELL_KIND_BAR_MAX_N) ){
+			break;
+		}
 		chr_cast_spell_normal( chr, FALSE, tab, _100_PERCENT );
 		break;
 	case EXTENT_KIND_SPREAD:
@@ -868,6 +898,44 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 
 /**/
 
+void	play_sound_spell( chr_t *chr, spell_kind_t kind )
+{
+	if( (SPELL_KIND_MAG_MIN_N < kind)
+			&& (kind < SPELL_KIND_MAG_MAX_N) ){
+		call_game_sound_play( SOUND_KIND_SPELL_MAG, 1 );
+	}
+	if( (SPELL_KIND_SOR_MIN_N < kind)
+			&& (kind < SPELL_KIND_SOR_MAX_N) ){
+		call_game_sound_play( SOUND_KIND_SPELL_SOR, 1 );
+	}
+	if( (SPELL_KIND_ENC_MIN_N < kind)
+			&& (kind < SPELL_KIND_ENC_MAX_N) ){
+		call_game_sound_play( SOUND_KIND_SPELL_ENC, 1 );
+	}
+	if( (SPELL_KIND_SUM_MIN_N < kind)
+			&& (kind < SPELL_KIND_SUM_MAX_N) ){
+		call_game_sound_play( SOUND_KIND_SPELL_SUM, 1 );
+	}
+	if( (SPELL_KIND_PRI_MIN_N < kind)
+			&& (kind < SPELL_KIND_PRI_MAX_N) ){
+		call_game_sound_play( SOUND_KIND_SPELL_PRI, 1 );
+	}
+	if( (SPELL_KIND_SHA_MIN_N < kind)
+			&& (kind < SPELL_KIND_SHA_MAX_N) ){
+		call_game_sound_play( SOUND_KIND_SPELL_SHA, 1 );
+	}
+	if( (SPELL_KIND_BAR_MIN_N < kind)
+			&& (kind < SPELL_KIND_BAR_MAX_N) ){
+		call_game_sound_play( SOUND_KIND_SPELL_BAR, 1 );
+	}
+	if( (SPELL_KIND_NIN_MIN_N < kind)
+			&& (kind < SPELL_KIND_NIN_MAX_N) ){
+		call_game_sound_play( SOUND_KIND_SPELL_NIN, 1 );
+	}
+}
+
+/**/
+
 void	chr_cast_spell_normal(
 	chr_t *chr, bool_t flg_item,
 	spell_tab_t *tab, rate_t rate
@@ -960,6 +1028,7 @@ void	chr_cast_spell_blast(
 	long	xx, yy;
 	bool_t	flg_actual;
 	chr_kind_t	kind;
+	chr_t	*trgt_chr;
 
 	if( chr == NULL )
 		return;
@@ -975,6 +1044,18 @@ void	chr_cast_spell_blast(
 	else
 		kind = CHR_KIND_NULL;
 
+	if( is_mnstr( chr ) ){
+		if( chk_flg( chr->flg_map, FLG_MAP_CHR_FIND ) ){
+			call_game_sound_play(
+					SOUND_KIND_BLAST_MONSTER, 1 );
+		}
+	} else if( is_mbr( chr ) ){
+		if( chk_flg( chr->flg_map, FLG_MAP_CHR_FIND ) ){
+			call_game_sound_play(
+					SOUND_KIND_BLAST_MEMBER, 1 );
+		}
+	}
+
 	blast = get_blast_spell( tab->kind );
 	blast_str = get_spell_vfx_str( tab->kind );
 	draw_blast( kind, x, y, blast, blast_str );
@@ -983,6 +1064,7 @@ void	chr_cast_spell_blast(
 
 	flg_actual = chk_flg( get_flg_party(), FLG_PARTY_ACTUAL_FIGHTING );
 
+	clr_all_chr_flg_blast();
 	bgn_sync_vfx_num();
 
 	for( ny = 0; ny < blast->yl; ny++ ){
@@ -993,11 +1075,13 @@ void	chr_cast_spell_blast(
 			xx = x + nx - (blast->xr / 2);
 			yy = y + ny - blast->yr;
 
+			trgt_chr = NULL;
 			p = NULL;
 
 			switch( trgt_kind ){
 			case TRGT_KIND_MBR:
-				p = get_mbr( xx, yy );
+				trgt_chr = get_mbr( xx, yy );
+				p = trgt_chr;
 				break;
 			case TRGT_KIND_NULL:
 			case TRGT_KIND_MNSTR:
@@ -1006,7 +1090,8 @@ void	chr_cast_spell_blast(
 			case TRGT_KIND_POS:
 				trgt_kind = TRGT_KIND_MNSTR;
 
-				p = get_mnstr( xx, yy );
+				trgt_chr = get_mnstr( xx, yy );
+				p = trgt_chr;
 				if( p == NULL )
 					break;
 				if( p == chr )
@@ -1040,6 +1125,17 @@ void	chr_cast_spell_blast(
 			if( p == NULL )
 				continue;
 
+			/* äƤ̵ */
+
+			if( trgt_chr != NULL ){
+				if( chk_flg( trgt_chr->work.flg,
+						FLG_WORK_BLAST_END ) ){
+					continue;
+				}
+
+				trgt_chr->work.flg |= FLG_WORK_BLAST_END;
+			}
+
 			draw_map( xx, yy, 1, 1 );
 
 			chr_cast_spell_sub( chr, flg_item, tab, rate,
@@ -1048,6 +1144,7 @@ void	chr_cast_spell_blast(
 	}
 
 	end_sync_vfx_num();
+	clr_all_chr_flg_blast();
 
 	draw_blast( kind, x, y, blast, blast_str );
 	if( clip_draw_pos( x, y ) )
@@ -1652,7 +1749,7 @@ void	chr_cast_spell_sub(
 		fx_store_light( chr );
 		break;
 	case SPELL_KIND_TELEPORT_PARTY:
-		fx_teleport_party();
+		fx_teleport_party_charge();
 		break;
 	case SPELL_KIND_TELEPORT:
 		fx_teleport( trgt_kind, p );
@@ -2022,7 +2119,7 @@ void	chr_cast_spell_sub(
 		fx_dispel_undead( chr, trgt_kind, (chr_t *)p, rate );
 		break;
 	case SPELL_KIND_ESCAPE:
-		fx_teleport_party();
+		fx_teleport_party_charge();
 		break;
 	case SPELL_KIND_SANCTUARY:
 		fx_sanctuary( chr, ABL_KIND_PRI );
