@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.145 2009/05/24 03:55:25 bowkenken Exp $
+* $Id: tmenu.c,v 1.149 2009/06/01 05:05:04 bowkenken Exp $
 ***************************************************************/
 
 #define	TMENU_C
@@ -138,10 +138,10 @@ char	*menu_shop_sel_mbr( shop_n_t shop_n, bool_t flg_pet )
 		flg_sel_dead = FALSE;
 
 	while( 1 ){
-		char	ttl[MENU_MSG_MAX_LEN + 1];
+		char	ttl[MENU_MSG_MAX_BYTE + 1];
 		char	*str_goto;
 
-		sn_printf( ttl, MENU_MSG_MAX_LEN, MSG_MENU_SHOP_SEL_MBR,
+		sn_printf( ttl, MENU_MSG_MAX_BYTE, MSG_MENU_SHOP_SEL_MBR,
 				get_shop_name( g_shop_n ) );
 
 		str_goto = exec_menu_sel_mbr(
@@ -212,7 +212,7 @@ char	*cb_menu_temple_init( menu_t **pp, menu_t **dflt )
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_TEMPLE,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE, MSG_TTL_MENU_TEMPLE,
 			get_shop_name( SHOP_N_TEMPLE ),
 			g_sel_mbr->name, fmt_gold( g_sel_mbr->gold ) );
 
@@ -221,7 +221,7 @@ char	*cb_menu_temple_init( menu_t **pp, menu_t **dflt )
 	if( p == NULL )
 		return STR_MENU_ERR;
 	len = get_pading_len( MSG( p->n_msg ), max_len );
-	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_FMT_MENU_TEMPLE,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE, MSG_FMT_MENU_TEMPLE,
 			len, MSG( p->n_msg ), fmt_gold( price ) );
 
 	price = get_price_temple_cure_status( g_sel_mbr );
@@ -229,7 +229,7 @@ char	*cb_menu_temple_init( menu_t **pp, menu_t **dflt )
 	if( p == NULL )
 		return STR_MENU_ERR;
 	len = get_pading_len( MSG( p->n_msg ), max_len );
-	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_FMT_MENU_TEMPLE,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE, MSG_FMT_MENU_TEMPLE,
 			len, MSG( p->n_msg ), fmt_gold( price ) );
 
 	price = get_price_temple_resurrection( g_sel_mbr );
@@ -237,7 +237,7 @@ char	*cb_menu_temple_init( menu_t **pp, menu_t **dflt )
 	if( p == NULL )
 		return STR_MENU_ERR;
 	len = get_pading_len( MSG( p->n_msg ), max_len );
-	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_FMT_MENU_TEMPLE,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE, MSG_FMT_MENU_TEMPLE,
 			len, MSG( p->n_msg ), fmt_gold( price ) );
 
 	return NULL;
@@ -519,7 +519,7 @@ char	*menu_order_sel_mbr( void )
 	str_nz_cpy( p[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	p[k].accel_key = '\0';
 	p[k].short_key[0] = '\0';
-	str_nz_cpy( p[k].msg, MSG_TTL_MENU_ORDER, MENU_MSG_MAX_LEN );
+	str_nz_cpy( p[k].msg, MSG_TTL_MENU_ORDER, MENU_MSG_MAX_BYTE );
 	p[k].call_back = NULL;
 	p[k].arg = NULL;
 	p[k].flg = FLG_NULL;
@@ -547,7 +547,7 @@ char	*menu_order_sel_mbr( void )
 			name = MSG_MENU_ORDER_NULL;
 		else
 			name = g_mbr_order[i]->name;
-		sn_printf( p[k].msg, MENU_MSG_MAX_LEN,
+		sn_printf( p[k].msg, MENU_MSG_MAX_BYTE,
 				MSG_MENU_ORDER_MBR, mbr[i]->name, name );
 		p[k].call_back = cb_menu_order_sel;
 		p[k].arg = mbr[i];
@@ -564,7 +564,7 @@ char	*menu_order_sel_mbr( void )
 	str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 	p[k].accel_key = 'Z';
 	p[k].short_key[0] = '\0';
-	str_nz_cpy( p[k].msg, MSG_MENU_ORDER_CHOSE, MENU_MSG_MAX_LEN );
+	str_nz_cpy( p[k].msg, MSG_MENU_ORDER_CHOSE, MENU_MSG_MAX_BYTE );
 	p[k].call_back = cb_menu_order_chose;
 	p[k].arg = NULL;
 	p[k].flg = FLG_NULL;
@@ -660,7 +660,7 @@ char	*cb_menu_order_chose( menu_t **pp, menu_t **dflt )
 			continue;
 
 		add_chr_gold( pty->mbr[i], -price );
-		call_game_sound_play( SOUND_KIND_SHOP_DRINK, 2 );
+		call_game_sound_play( SOUND_KIND_SHOP_BUY_DRINK, 2 );
 
 		tmp = alloc_item();
 		if( tmp == NULL )
@@ -810,7 +810,7 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 			ls[k].accel_key = '\0';
 			ls[k].short_key[0] = '\0';
 			sn_printf( ls[k].msg,
-					MENU_MSG_MAX_LEN,
+					MENU_MSG_MAX_BYTE,
 					MSG_FMT_MENU_SHOP,
 					get_shop_name( shop_n ),
 					mbr->name, buy_sale,
@@ -861,7 +861,7 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
 		sn_printf( ls[k].msg,
-				MENU_MSG_MAX_LEN,
+				MENU_MSG_MAX_BYTE,
 				MSG_FMT_MENU_SHOP,
 				get_shop_name( shop_n ),
 				mbr->name, buy_sale,
@@ -883,7 +883,7 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 			continue;
 
 		sn_printf( ls[i].msg,
-				MENU_MSG_MAX_LEN,
+				MENU_MSG_MAX_BYTE,
 				MSG_FMT_ART_NAME,
 				max_len, ls_art[j]->art_name,
 				fmt_gold( get_price(
@@ -908,7 +908,7 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 	str_nz_cpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
 	ls[*k].accel_key = 'T';
 	ls[*k].short_key[0] = '\0';
-	str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_DATA, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_DATA, MENU_MSG_MAX_BYTE );
 	ls[*k].call_back = cb_menu_shop_data;
 	ls[*k].arg = NULL;
 	ls[*k].flg = FLG_NULL;
@@ -921,7 +921,7 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 	ls[*k].accel_key = 'U';
 	ls[*k].short_key[0] = '\0';
 	str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_COLLECT_GOLD,
-			MENU_MSG_MAX_LEN );
+			MENU_MSG_MAX_BYTE );
 	ls[*k].call_back = cb_menu_shop_collect_gold;
 	ls[*k].arg = NULL;
 	ls[*k].flg = FLG_NULL;
@@ -934,7 +934,7 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 	ls[*k].accel_key = 'V';
 	ls[*k].short_key[0] = '\0';
 	str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_DIVIDE_GOLD,
-			MENU_MSG_MAX_LEN );
+			MENU_MSG_MAX_BYTE );
 	ls[*k].call_back = cb_menu_shop_divide_gold;
 	ls[*k].arg = NULL;
 	ls[*k].flg = FLG_NULL;
@@ -947,7 +947,7 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 	ls[*k].accel_key = 'W';
 	ls[*k].short_key[0] = '\0';
 	str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_GIVE_GOLD,
-			MENU_MSG_MAX_LEN );
+			MENU_MSG_MAX_BYTE );
 	ls[*k].call_back = cb_menu_shop_give_gold;
 	ls[*k].arg = NULL;
 	ls[*k].flg = FLG_NULL;
@@ -963,7 +963,7 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 			ls[*k].accel_key = 'X';
 			ls[*k].short_key[0] = '\0';
 			str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_SALE_EQUIP,
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 			ls[*k].call_back = cb_menu_shop_sale_equip;
 			ls[*k].arg = NULL;
 			ls[*k].flg = FLG_NULL;
@@ -979,7 +979,7 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 			ls[*k].accel_key = 'Y';
 			ls[*k].short_key[0] = '\0';
 			str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_SALE_ITEM,
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 			ls[*k].call_back = cb_menu_shop_sale_item;
 			ls[*k].arg = NULL;
 			ls[*k].flg = FLG_NULL;
@@ -995,7 +995,7 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 			ls[*k].accel_key = 'Z';
 			ls[*k].short_key[0] = '\0';
 			str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_BUY,
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 			ls[*k].call_back = cb_menu_shop_buy;
 			ls[*k].arg = NULL;
 			ls[*k].flg = FLG_NULL;
@@ -1134,6 +1134,7 @@ char	*cb_menu_shop( menu_t **pp, menu_t **dflt )
 			return STR_MENU_CANCEL;
 
 		add_chr_gold( g_sel_mbr, -(price * deal_n / n) );
+		call_game_sound_play( SOUND_KIND_SHOP_BUY, 1 );
 
 	} else if( g_deal_kind == DEAL_KIND_SALE_ITEM ){
 		deal_n = menu_shop_sale_item( g_shop_n, g_sel_mbr, art );
@@ -1141,6 +1142,7 @@ char	*cb_menu_shop( menu_t **pp, menu_t **dflt )
 			return STR_MENU_CANCEL;
 
 		add_chr_gold( g_sel_mbr, +(price * deal_n / n) );
+		call_game_sound_play( SOUND_KIND_SHOP_SALE, 1 );
 
 	} else if( g_deal_kind == DEAL_KIND_SALE_EQUIP ){
 		deal_n = menu_shop_sale_equip( g_shop_n, g_sel_mbr, art );
@@ -1148,8 +1150,8 @@ char	*cb_menu_shop( menu_t **pp, menu_t **dflt )
 			return STR_MENU_CANCEL;
 
 		add_chr_gold( g_sel_mbr, +(price * deal_n / n) );
+		call_game_sound_play( SOUND_KIND_SHOP_SALE, 1 );
 	}
-	call_game_sound_play( SOUND_KIND_SHOP_PAY, 1 );
 
 	return "/shop";
 }
@@ -1663,7 +1665,7 @@ char	*cb_menu_bar_form( menu_t **pp, menu_t **dflt )
 		p[k].accel_key = '\0';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_TTL_MENU_BAR_FORM,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = NULL;
 		p[k].arg = NULL;
 		p[k].flg = FLG_NULL;
@@ -1685,7 +1687,7 @@ char	*cb_menu_bar_form( menu_t **pp, menu_t **dflt )
 			p[k].accel_key = (char)('A' + j);
 			p[k].short_key[0] = '\0';
 			str_nz_cpy( p[k].msg, ls_mbr[ls_mbr_n]->name,
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 			p[k].call_back = cb_menu_bar_form_sub;
 			p[k].arg = ls_mbr[ls_mbr_n];
 			p[k].flg = FLG_NULL;
@@ -1759,7 +1761,7 @@ char	*cb_menu_bar_form_sub( menu_t **pp, menu_t **dflt )
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	str_nz_cpy( p->msg, g_sel_ls_mbr->name, MENU_MSG_MAX_LEN );
+	str_nz_cpy( p->msg, g_sel_ls_mbr->name, MENU_MSG_MAX_BYTE );
 
 	return NULL;
 }
@@ -1832,7 +1834,7 @@ char	*cb_menu_bar_join( menu_t **pp, menu_t **dflt )
 				MENU_KIND_MAX_LEN );
 		p[k].accel_key = (char)('A' + i);
 		p[k].short_key[0] = '\0';
-		sn_printf( p[k].msg, MENU_MSG_MAX_LEN, "%ld", i + 1 );
+		sn_printf( p[k].msg, MENU_MSG_MAX_BYTE, "%ld", i + 1 );
 		p[k].call_back = cb_menu_bar_join_sub;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -1975,7 +1977,7 @@ char	*cb_menu_bar_edit_mbr( menu_t **pp, menu_t **dflt )
 		p[k].accel_key = '\0';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_TTL_MENU_BAR_EDIT_MBR,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = NULL;
 		p[k].arg = NULL;
 		p[k].flg = FLG_NULL;
@@ -1998,7 +2000,7 @@ char	*cb_menu_bar_edit_mbr( menu_t **pp, menu_t **dflt )
 			p[k].accel_key = (char)('A' + j);
 			p[k].short_key[0] = '\0';
 			str_nz_cpy( p[k].msg, ls_mbr[ls_mbr_n]->name,
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 			p[k].call_back = cb_menu_bar_edit_mbr_sub;
 			p[k].arg = ls_mbr[ls_mbr_n];
 			p[k].flg = FLG_NULL;
@@ -2066,7 +2068,7 @@ char	*cb_menu_bar_edit_mbr_sub( menu_t **pp, menu_t **dflt )
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_BAR_EDIT_MBR_SUB,
 			g_sel_ls_mbr->name );
 
@@ -2238,7 +2240,7 @@ bool_t	exec_menu_new_mbr( void )
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_NULL;
-	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[n], MSG_MENU_NEW_MBR,
 			'@', race, MALE, 0, n );
 
@@ -2306,7 +2308,7 @@ char	*cb_menu_bar_remove_mbr( menu_t **pp, menu_t **dflt )
 		p[k].accel_key = '\0';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_TTL_MENU_BAR_REMOVE_MBR,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = NULL;
 		p[k].arg = NULL;
 		p[k].flg = FLG_NULL;
@@ -2329,7 +2331,7 @@ char	*cb_menu_bar_remove_mbr( menu_t **pp, menu_t **dflt )
 			p[k].accel_key = (char)('A' + j);
 			p[k].short_key[0] = '\0';
 			str_nz_cpy( p[k].msg, ls_mbr[ls_mbr_n]->name,
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 			p[k].call_back = cb_menu_bar_remove_mbr_sub;
 			p[k].arg = ls_mbr[ls_mbr_n];
 			p[k].flg = FLG_NULL;
@@ -2566,7 +2568,7 @@ char	*cb_menu_bar_new_class( menu_t **pp, menu_t **dflt )
 		return STR_MENU_ERR;
 	}
 
-	str_nz_cpy( p[n].name, MSG_MENU_NEW_CLASS, CLASS_NAME_MAX_LEN );
+	str_nz_cpy( p[n].name, MSG_MENU_NEW_CLASS, CLASS_NAME_MAX_BYTE );
 	for( i = 0; i < ABL_KIND_MAX_N; i++ )
 		p[n].abl_rate[i] = (rate_t)0;
 	for( i = 0; i < SKILL_MAX_N; i++ )
@@ -2883,7 +2885,7 @@ char	*exec_sel_skill( skill_kind_t *ret_kind )
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg,
 				get_skill_group_name( (skill_group_kind_t)i ),
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = NULL;
 		p[k].arg = NULL;
 		p[k].flg = FLG_NULL;
@@ -2898,7 +2900,7 @@ char	*exec_sel_skill( skill_kind_t *ret_kind )
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg,
 				get_skill_name_from_kind( kind ),
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_sel_skill;
 		p[k].arg = (void *)kind;
 		p[k].flg = FLG_NULL;
@@ -2921,7 +2923,7 @@ char	*exec_sel_skill( skill_kind_t *ret_kind )
 			p[k].short_key[0] = '\0';
 			str_nz_cpy( p[k].msg,
 					get_skill_name_from_kind( kind ),
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 			p[k].call_back = cb_menu_sel_skill;
 			p[k].arg = (void *)kind;
 			p[k].flg = FLG_NULL;
@@ -3172,10 +3174,7 @@ char	*cb_menu_load_bar( menu_t **pp, menu_t **dflt )
 {
 	menu_load_bar();
 
-/*@@@*/
 	return NULL;
-	return "/";
-	return "/bar";
 }
 
 /**/
@@ -3222,7 +3221,7 @@ char	*menu_inn( void )
 	p = srch_menu( ls_menu_inn, "stay" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_MENU_INN_STAY,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE, MSG_MENU_INN_STAY,
 			fmt_gold( get_price_inn( FALSE ) ) );
 
 	/* ٷ */
@@ -3230,7 +3229,7 @@ char	*menu_inn( void )
 	p = srch_menu( ls_menu_inn, "short stay" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_MENU_INN_SHORT_STAY,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE, MSG_MENU_INN_SHORT_STAY,
 			fmt_gold( get_price_inn( TRUE ) ) );
 
 	/* Ͼǰ */
@@ -3238,7 +3237,7 @@ char	*menu_inn( void )
 	p = srch_menu( ls_menu_inn, "stay in mews" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_MENU_INN_STAY_IN_MEWS,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE, MSG_MENU_INN_STAY_IN_MEWS,
 			fmt_gold( 0 ) );
 
 	/**/
@@ -3350,7 +3349,7 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_MAGIC_GUILD,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE, MSG_TTL_MENU_MAGIC_GUILD,
 			get_shop_name( SHOP_N_MAGIC ),
 			g_sel_mbr->name,
 			fmt_gold( g_sel_mbr->gold ) );
@@ -3383,12 +3382,12 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 		tab = get_spell_tab( kind );
 		if( tab == NULL ){
 			gold = 0;
-			sn_printf( ls[i].msg, MENU_MSG_MAX_LEN,
+			sn_printf( ls[i].msg, MENU_MSG_MAX_BYTE,
 					MSG_FMT_MENU_MAGIC_GUILD,
 					"", 0, fmt_gold( 0 ) );
 		} else {
 			gold = get_price_spell( kind );
-			sn_printf( ls[i].msg, MENU_MSG_MAX_LEN,
+			sn_printf( ls[i].msg, MENU_MSG_MAX_BYTE,
 					MSG_FMT_MENU_MAGIC_GUILD,
 					tab->name, tab->lev,
 					fmt_gold( gold ) );
@@ -3494,7 +3493,7 @@ char	*cb_menu_magic_guild( menu_t **pp, menu_t **dflt )
 	}
 
 	add_chr_gold( g_sel_mbr, -get_price_spell( kind ) );
-	call_game_sound_play( SOUND_KIND_SHOP_PAY, 1 );
+	call_game_sound_play( SOUND_KIND_SHOP_BUY, 1 );
 	set_chr_learned_spell( g_sel_mbr, kind, TRUE );
 
 	return "/magic guild";
@@ -3519,7 +3518,7 @@ char	*cb_menu_pet_shop_init( menu_t **pp, menu_t **dflt )
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_PET_SHOP,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE, MSG_TTL_MENU_PET_SHOP,
 			get_shop_name( SHOP_N_PET_SHOP ),
 			g_sel_mbr->name,
 			fmt_gold( g_sel_mbr->gold ) );
@@ -3561,7 +3560,8 @@ char	*cb_menu_pet_shop_take( menu_t **pp, menu_t **dflt )
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_PET_SHOP_TAKE,
+	sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
+			MSG_TTL_MENU_PET_SHOP_TAKE,
 			get_shop_name( SHOP_N_PET_SHOP ),
 			g_sel_mbr->name );
 	ls[k].call_back = NULL;
@@ -3583,7 +3583,8 @@ char	*cb_menu_pet_shop_take( menu_t **pp, menu_t **dflt )
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
-		str_nz_cpy( ls[k].msg, ls_pet[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, ls_pet[i]->name,
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_pet_shop_take_sel;
 		ls[k].arg = (void *)(ls_pet[i]);
 		ls[k].flg = FLG_NULL;
@@ -3675,7 +3676,8 @@ char	*cb_menu_pet_shop_leave( menu_t **pp, menu_t **dflt )
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_PET_SHOP_LEAVE,
+	sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
+			MSG_TTL_MENU_PET_SHOP_LEAVE,
 			get_shop_name( SHOP_N_PET_SHOP ),
 			g_sel_mbr->name );
 	ls[k].call_back = NULL;
@@ -3697,7 +3699,8 @@ char	*cb_menu_pet_shop_leave( menu_t **pp, menu_t **dflt )
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
-		str_nz_cpy( ls[k].msg, party_pet[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, party_pet[i]->name,
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_pet_shop_leave_sel;
 		ls[k].arg = (void *)(party_pet[i]);
 		ls[k].flg = FLG_NULL;
@@ -3784,12 +3787,14 @@ char	*cb_menu_pet_shop_name( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	str_nz_cpy( ls[k].path, "/pet shop name/title", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/pet shop name/title",
+			MENU_PATH_MAX_LEN );
 	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_PET_SHOP_NAME,
+	sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
+			MSG_TTL_MENU_PET_SHOP_NAME,
 			get_shop_name( SHOP_N_PET_SHOP ),
 			g_sel_mbr->name );
 	ls[k].call_back = NULL;
@@ -3814,7 +3819,7 @@ char	*cb_menu_pet_shop_name( menu_t **pp, menu_t **dflt )
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
-		sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+		sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
 				MSG_MENU_PET_SHOP_NAME_LS,
 				ls_pet[i]->name, mnstr_name );
 		ls[k].call_back = cb_menu_pet_shop_name_sel;
@@ -3911,7 +3916,7 @@ char	*cb_menu_pet_shop_remove( menu_t **pp, menu_t **dflt )
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+	sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_PET_SHOP_REMOVE,
 			get_shop_name( SHOP_N_PET_SHOP ),
 			g_sel_mbr->name );
@@ -3932,7 +3937,7 @@ char	*cb_menu_pet_shop_remove( menu_t **pp, menu_t **dflt )
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
-		str_nz_cpy( ls[k].msg, ls_pet[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, ls_pet[i]->name, MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_pet_shop_remove_sel;
 		ls[k].arg = (void *)(ls_pet[i]);
 		ls[k].flg = FLG_NULL;
@@ -4041,7 +4046,7 @@ char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt )
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_PET_SHOP,
+	sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE, MSG_TTL_MENU_PET_SHOP,
 			get_shop_name( SHOP_N_PET_SHOP ),
 			g_sel_mbr->name,
 			fmt_gold( g_sel_mbr->gold ) );
@@ -4078,7 +4083,7 @@ char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt )
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
-		sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+		sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
 				MSG_FMT_MENU_PET_SHOP,
 				get_mnstr_name( art_ls_pet_shop[i].kind ),
 				fmt_gold( art_ls_pet_shop[i].price ) );
@@ -4150,7 +4155,7 @@ char	*cb_menu_pet_shop_buy_sel( menu_t **pp, menu_t **dflt )
 	print_msg( FLG_NULL, MSG_MENU_PET_SHOP_BUY_SUCCESS, pet->name );
 
 	add_chr_gold( g_sel_mbr, (gold_t)(-price) );
-	call_game_sound_play( SOUND_KIND_SHOP_PAY, 1 );
+	call_game_sound_play( SOUND_KIND_SHOP_BUY, 1 );
 
 	return "/pet shop";
 }
@@ -4192,7 +4197,7 @@ char	*cb_menu_navi_init( menu_t **pp, menu_t **dflt )
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	str_nz_cpy( ls[k].msg, MSG_TTL_MENU_NAVI, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_TTL_MENU_NAVI, MENU_MSG_MAX_BYTE );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -4222,7 +4227,8 @@ char	*cb_menu_navi_init( menu_t **pp, menu_t **dflt )
 		ls[k].accel_key = toupper( mnr );
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
-		str_nz_cpy( ls[k].msg, get_shop_name( n ), MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, get_shop_name( n ),
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_navi;
 		ls[k].arg = (void *)n;
 		ls[k].flg = FLG_NULL;
@@ -4323,7 +4329,7 @@ bool_t	set_menu_auto_sale( menu_t *ls, mbr_t *mbr )
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+	sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_AUTO_SALE, mbr->name );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
@@ -4367,7 +4373,7 @@ bool_t	set_menu_auto_sale( menu_t *ls, mbr_t *mbr )
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
 		sn_printf( ls[k].msg,
-				MENU_MSG_MAX_LEN,
+				MENU_MSG_MAX_BYTE,
 				MSG_FMT_ART_NAME,
 				max_len,
 				item->art_name,
@@ -4458,7 +4464,7 @@ char	*cb_menu_auto_sale_exec( menu_t **pp, menu_t **dflt )
 	if( sale_sum <= 0 )
 		return NULL;
 
-	call_game_sound_play( SOUND_KIND_SHOP_PAY, 1 );
+	call_game_sound_play( SOUND_KIND_SHOP_SALE, 1 );
 
 	add_turn( NAVI_ADD_TURN_N + SHOP_ADD_TURN_N );
 
