@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town.c,v 1.140 2008/10/02 09:21:05 bowkenken Exp $
+* $Id: town.c,v 1.155 2009/06/21 12:39:41 bowkenken Exp $
 ***************************************************************/
 
 #define	TOWN_C
@@ -124,7 +124,8 @@
 #define	PRICE_WPN_MUL_TYPE_MUL	500
 #define	PRICE_WPN_MUL_TYPE_BASE	0
 
-#define	PRICE_WPN_SLAYER	10000
+#define	PRICE_WPN_SLAYER	2000
+#define	PRICE_WPN_RANDM_ART	2000
 
 #define	PRICE_DAGGER_DIV	400
 #define	PRICE_ARW_DIV	500
@@ -161,6 +162,8 @@
 #define	PRICE_ARMOR_ADD_CRTCL_BASE	0
 #define	PRICE_ARMOR_ADD_AC_BASE	0
 
+#define	PRICE_ARMOR_RANDM_ART	2000
+
 /* ڴ */
 
 #define	PRICE_INST_BASE	1000
@@ -549,7 +552,9 @@ bool_t	trans_town_ptn( town_ptn_t *dst, town_ptn_t *src )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* 
+***************************************************************/
 
 void	make_town( void )
 {
@@ -653,7 +658,9 @@ void	make_town( void )
 	make_request_all();
 }
 
-/**/
+/***************************************************************
+* Υѥ󤫤ޥåפ
+***************************************************************/
 
 void	make_town_ptn( void )
 {
@@ -690,7 +697,12 @@ void	make_town_ptn( void )
 	}
 }
 
-/**/
+/***************************************************************
+* ɸΥޥåפΤ
+* town_ptn_t *ptn : ѥ
+* long x : X ɸ
+* long y : Y ɸ
+***************************************************************/
 
 void	make_field_town( town_ptn_t *ptn, long x, long y )
 {
@@ -740,6 +752,7 @@ void	make_field_town( town_ptn_t *ptn, long x, long y )
 		}
 		if( mnr != FACE_MNR_HOLE )
 			flg |= FLG_MAP_OBJ_PASS;
+		flg |= FLG_MAP_OBJ_LOOK;
 		break;
 	case FACE_MJR_DOOR_OPEN:
 		mjr = FACE_MJR_DOOR_CLOSE;
@@ -748,7 +761,7 @@ void	make_field_town( town_ptn_t *ptn, long x, long y )
 		break;
 	case FACE_MJR_STAIRS_UP:
 	case FACE_MJR_STAIRS_DOWN:
-		flg |= FLG_MAP_OBJ_PASS;
+		flg |= FLG_MAP_OBJ_PASS | FLG_MAP_OBJ_LOOK;
 		break;
 	default:
 		print_msg( FLG_NULL, MSG_S, MSG_ERR_TOWN_MAP );
@@ -764,7 +777,12 @@ void	make_field_town( town_ptn_t *ptn, long x, long y )
 	dun->map.sect[y][x] = SECT_NULL;
 }
 
-/**/
+/***************************************************************
+* ʤĥ
+* long x : X ɸ
+* long y : Y ɸ
+* return : 顼̵ä
+***************************************************************/
 
 bool_t	extend_stairs( long x, long y )
 {
@@ -802,7 +820,9 @@ bool_t	extend_stairs( long x, long y )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* 
+***************************************************************/
 
 void	make_streetlamp( void )
 {
@@ -825,7 +845,11 @@ void	make_streetlamp( void )
 	}
 }
 
-/**/
+/***************************************************************
+* 
+* long x : X ɸ
+* long y : Y ɸ
+***************************************************************/
 
 void	on_streetlamp( long x, long y )
 {
@@ -846,7 +870,12 @@ void	on_streetlamp( long x, long y )
 	}
 }
 
-/**/
+/***************************************************************
+* Źξʤ
+* shop_n_t shop_n : Źֹ
+* void *art_ls : ʥǡꥹȡ
+* return : 
+***************************************************************/
 
 bool_t	make_art_town( shop_n_t shop_n, void *art_ls )
 {
@@ -1198,7 +1227,12 @@ bool_t	make_art_town( shop_n_t shop_n, void *art_ls )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* Υɥ
+* long mx : X ɸ
+* long my : Y ɸ
+* char mnr : ޥʡδʸ
+***************************************************************/
 
 void	make_door_town( long mx, long my, char mnr )
 {
@@ -1234,7 +1268,9 @@ void	make_door_town( long mx, long my, char mnr )
 	make_door( mx, my, mx + dx, my + dy, mnr );
 }
 
-/**/
+/***************************************************************
+* ƤŹޥå׾ͭ뤫åǡꥻå
+***************************************************************/
 
 void	reset_shop_face_ls( void )
 {
@@ -1258,7 +1294,10 @@ void	reset_shop_face_ls( void )
 	}
 }
 
-/**/
+/***************************************************************
+* Źޥå׾ͭ뤫ɤΥե饰򥻥å
+* char mnr : ޥʡδʸ
+***************************************************************/
 
 bool_t	set_shop_face_ls( char mnr )
 {
@@ -1278,7 +1317,10 @@ bool_t	set_shop_face_ls( char mnr )
 	return FALSE;
 }
 
-/**/
+/***************************************************************
+* ƤŹޥå׾ͭ뤫å
+* return : ƤŹޥå׾ͭ뤫?
+***************************************************************/
 
 bool_t	chk_shop_face_ls( void )
 {
@@ -1291,7 +1333,10 @@ bool_t	chk_shop_face_ls( void )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ѡƥ򳹤˽и
+* return : иǤ?
+***************************************************************/
 
 bool_t	appear_party_town( void )
 {
@@ -1314,10 +1359,8 @@ bool_t	appear_party_town( void )
 			FACE_MNR_STAIRS_DOWN, &x, &y ) ){
 		return FALSE;
 	}
-	pty->square.x = x;
-	pty->square.y = y;
-	pty->square.pre_x = x;
-	pty->square.pre_y = y;
+	set_square_pos( x, y, FALSE );
+	set_square_pos( x, y, TRUE );
 
 	clr_map_all_mbr();
 	clr_map_all_pet();
@@ -1329,11 +1372,11 @@ bool_t	appear_party_town( void )
 				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) )
 			continue;
 
-		nx = pty->square.x + pty->square.chr_pos[n].x;
-		ny = pty->square.y + pty->square.chr_pos[n].y;
+		get_square_mbr_abs_pos( n, &nx, &ny );
 		put_chr( pty->mbr[n], nx, ny );
 	}
 
+	reset_mbr_dir();
 	appear_all_pet();
 
 	next_pos_square( 0 );
@@ -1345,7 +1388,11 @@ bool_t	appear_party_town( void )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ѡƥʥӤǰư
+* shop_n_t shop_n : Źֹ
+* return : ưǤ?
+***************************************************************/
 
 bool_t	navi_party( shop_n_t shop_n )
 {
@@ -1364,7 +1411,10 @@ bool_t	navi_party( shop_n_t shop_n )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ѡƥʥӤǳʤذư
+* return : ưǤ?
+***************************************************************/
 
 bool_t	navi_party_stairs()
 {
@@ -1377,7 +1427,11 @@ bool_t	navi_party_stairs()
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* Ź뤿ΥѡƥΥ
+* long n : ɥֹ
+* return : 顼̵ä
+***************************************************************/
 
 bool_t	open_door_shop( long n )
 {
@@ -1402,7 +1456,10 @@ bool_t	open_door_shop( long n )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ѡƥŹ
+* return : 顼̵ä
+***************************************************************/
 
 bool_t	enter_shop( void )
 {
@@ -1417,6 +1474,8 @@ bool_t	enter_shop( void )
 	pty = get_party();
 	pet = get_party_pet();
 
+	set_flg_exit_shop( TRUE );
+
 	if( pty->act.kind != ACT_KIND_SHOP )
 		return FALSE;
 
@@ -1470,7 +1529,8 @@ bool_t	enter_shop( void )
 			print_msg( FLG_MSG_ERR, MSG_S,
 					MSG_ERR_NOT_EXIST_ALL_MBR );
 		} else {
-			party_exit_shop( dr_n );
+			if( get_flg_exit_shop() )
+				party_exit_shop( dr_n );
 			break;
 		}
 	}
@@ -1478,10 +1538,14 @@ bool_t	enter_shop( void )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ѡƥŹФ
+* long dr_n : ɥֹ
+***************************************************************/
 
 void	party_exit_shop( long dr_n )
 {
+	long	seed;
 	dun_t	*dun;
 	party_t	*pty;
 	long	x, y;
@@ -1489,6 +1553,8 @@ void	party_exit_shop( long dr_n )
 	bool_t	flg_force;
 	long	i, j;
 
+	seed = get_randm_seed();
+
 	dun = get_dun();
 	pty = get_party();
 
@@ -1543,19 +1609,17 @@ void	party_exit_shop( long dr_n )
 	} else {
 		/* ̤˽Ф */
 
-		pty->square.x = x + 1;
-		pty->square.y = y + 1;
-
+		set_square_pos( x + 1, y + 1, FALSE );
 		clr_map_all_mbr();
 
 		for( j = 0; j < MBR_MAX_N; j++ ){
 			long	x, y;
 
-			x = pty->square.x + pty->square.chr_pos[j].x;
-			y = pty->square.y + pty->square.chr_pos[j].y;
+			get_square_mbr_abs_pos( j, &x, &y );
 			put_chr( pty->mbr[j], x, y );
 		}
 
+		reset_mbr_dir();
 		appear_all_pet();
 	}
 
@@ -1564,15 +1628,21 @@ void	party_exit_shop( long dr_n )
 	set_flg_find_all_mnstr();
 	wipe_menu();
 
-	move_crsr_abs( pty->square.x, pty->square.y );
+	get_square_pos( &x, &y, FALSE );
+	move_crsr_abs( x, y );
 
 	if( dun->door[dr_n].mnr != FACE_MNR_SHOP_BAR )
 		add_turn( SHOP_ADD_TURN_N );
 
 	change_scene( SCENE_N_TOWN );
+
+	srandm( seed );
 }
 
-/**/
+/***************************************************************
+* ŹĹΤ
+* shop_n_t shop_n : Źֹ
+***************************************************************/
 
 void	say_welcome_shop_msg( shop_n_t shop_n )
 {
@@ -1654,7 +1724,12 @@ void	say_welcome_shop_msg( shop_n_t shop_n )
 	}
 }
 
-/**/
+/***************************************************************
+* ŹĹ֤̾
+* shop_n_t shop_n : Źֹ
+* sex_t sex : ŹĹ
+* return : ŹĹ̾
+***************************************************************/
 
 const char	*get_npc_name_shop( shop_n_t shop_n, sex_t sex )
 {
@@ -1727,7 +1802,11 @@ const char	*get_npc_name_shop( shop_n_t shop_n, sex_t sex )
 	return MSG_NPC_NAME_SHOP_NULL_MALE;
 }
 
-/**/
+/***************************************************************
+* ŹĹ̤֤
+* shop_n_t shop_n : Źֹ
+* return : ̤̾
+***************************************************************/
 
 sex_t	get_npc_sex_shop( shop_n_t shop_n )
 {
@@ -1766,7 +1845,9 @@ sex_t	get_npc_sex_shop( shop_n_t shop_n )
 	return MALE;
 }
 
-/**/
+/***************************************************************
+* ѡƥ
+***************************************************************/
 
 void	party_enter_bar( void )
 {
@@ -1780,20 +1861,32 @@ void	party_enter_bar( void )
 	enter_shop();
 }
 
-/**/
+/***************************************************************
+* ѡƥ줫Ф
+***************************************************************/
 
 void	party_exit_bar( void )
 {
 	door_t	*dr;
+	long	seed;
+
+	seed = get_randm_seed();
 
 	dr = get_shop_door( SHOP_N_BAR );
 	if( dr == NULL )
 		return;
 
+	srandm( seed );
+
 	party_exit_shop( dr->n );
 }
 
-/**/
+/***************************************************************
+* ŹαĶȻ椫Ĵ٤
+* shop_n_t shop_n : Źֹ
+* bool_t flg_print : åɽ뤫?
+* return : ŹαĶȻ椫?
+***************************************************************/
 
 bool_t	chk_shop_open( shop_n_t shop_n, bool_t flg_print )
 {
@@ -1878,7 +1971,11 @@ bool_t	chk_shop_open( shop_n_t shop_n, bool_t flg_print )
 	return ret;
 }
 
-/**/
+/***************************************************************
+* ʤޤȤꤹ뤫Ĵ٤
+* item_t *item : 
+* return : ޤȤꤹ뤫?
+***************************************************************/
 
 bool_t	chk_package_item( item_t *item )
 {
@@ -1920,7 +2017,11 @@ bool_t	chk_package_item( item_t *item )
 	return FALSE;
 }
 
-/**/
+/***************************************************************
+* ɲ
+* bool_t flg_short_stay : ٷƤ?
+* bool_t flg_mews : Ͼ뤫?
+***************************************************************/
 
 void	stay_inn( bool_t flg_short_stay, bool_t flg_mews )
 {
@@ -1965,7 +2066,8 @@ void	stay_inn( bool_t flg_short_stay, bool_t flg_mews )
 		/* ͤꥻå */
 		for( j = 0; j < RESI_KIND_MAX_N; j++ ){
 			reset_mbr_resi( mbr );
-			mbr->resi[j].n = mbr->resi[j].max;
+			mbr->resi[j].n = get_resi_max(
+					mbr, (resi_kind_t)j );
 		}
 
 		/* 줤 */
@@ -2003,7 +2105,8 @@ void	stay_inn( bool_t flg_short_stay, bool_t flg_mews )
 		/* ͤꥻå */
 		for( j = 0; j < RESI_KIND_MAX_N; j++ ){
 			reset_pet_resi( pet[i] );
-			pet[i]->resi[j].n = pet[i]->resi[j].max;
+			pet[i]->resi[j].n = get_resi_max(
+					pet[i], (resi_kind_t)j );
 		}
 
 		/* 줤 */
@@ -2070,7 +2173,13 @@ void	take_bath( chr_t *chr )
 	}
 }
 
-/**/
+/***************************************************************
+* ƥξ̾Ĥ
+* mbr_t *mbr : С
+* item_t *art : 
+* deal_kind_t kind : μ
+* return : 顼̵ä
+***************************************************************/
 
 bool_t	set_art_name( mbr_t *mbr, item_t *art, deal_kind_t kind )
 {
@@ -2109,7 +2218,13 @@ bool_t	set_art_name( mbr_t *mbr, item_t *art, deal_kind_t kind )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ξ̾Ĥ
+* mbr_t *mbr : С
+* item_t *art : 
+* equip_kind_t eq : μ
+* return : 顼̵ä
+***************************************************************/
 
 bool_t	set_art_name_equip( mbr_t *mbr, item_t *art, equip_kind_t eq )
 {
@@ -2166,7 +2281,7 @@ bool_t	set_art_name_equip( mbr_t *mbr, item_t *art, equip_kind_t eq )
 		break;
 	}
 	if( eq_name != NULL ){
-		sn_printf( art->art_name, ITEM_ART_NAME_MAX_LEN,
+		sn_printf( art->art_name, ITEM_ART_NAME_MAX_BYTE,
 				MSG_FMT_ART_NAME_EQUIP,
 				get_equip_ttl_max_len(), eq_name,
 				art->name );
@@ -2177,7 +2292,12 @@ bool_t	set_art_name_equip( mbr_t *mbr, item_t *art, equip_kind_t eq )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* Сʧ뤫Ĵ٤
+* mbr_t *mbr : С
+* gold_t price : 
+* return : ʧ뤫?
+***************************************************************/
 
 bool_t	chk_pay( mbr_t *mbr, gold_t price )
 {
@@ -2197,7 +2317,13 @@ bool_t	chk_pay( mbr_t *mbr, gold_t price )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ʤʤ׻
+* shop_n_t shop_n : Źֹ
+* item_t *item : 
+* deal_kind_t deal_kind : μ
+* return : ʤ
+***************************************************************/
 
 gold_t	get_price( shop_n_t shop_n, item_t *item, deal_kind_t deal_kind )
 {
@@ -2290,7 +2416,13 @@ gold_t	get_price( shop_n_t shop_n, item_t *item, deal_kind_t deal_kind )
 	return price;
 }
 
-/**/
+/***************************************************************
+* ʤʤ
+* gold_t price : 
+* shop_n_t shop_n : Źֹ
+* deal_kind_t deal_kind : μ
+* return : 
+***************************************************************/
 
 gold_t	discount( gold_t price, shop_n_t shop_n, deal_kind_t deal_kind )
 {
@@ -2312,7 +2444,11 @@ gold_t	discount( gold_t price, shop_n_t shop_n, deal_kind_t deal_kind )
 	return price;
 }
 
-/**/
+/***************************************************************
+* ʤ׻
+* item_t *item : 
+* return : 
+***************************************************************/
 
 gold_t	get_price_wpn( item_t *item )
 {
@@ -2335,7 +2471,7 @@ gold_t	get_price_wpn( item_t *item )
 
 	price = 0;
 
-	/**/
+	/* ܤ */
 
 	flg_dag = FALSE;
 	flg_arw = FALSE;
@@ -2393,7 +2529,7 @@ gold_t	get_price_wpn( item_t *item )
 	price = price * PRICE_WPN_RATE / _100_PERCENT;
 	price += PRICE_WPN_BASE;
 
-	/**/
+	/* ٹǽ */
 
 	if( item->dat.wpn.add_hit < 0 )
 		return( (gold_t)0 );
@@ -2419,7 +2555,7 @@ gold_t	get_price_wpn( item_t *item )
 			price += PRICE_WPN_ADD_DAM_BASE;
 	}
 
-	/**/
+	/* ʣι⥿ */
 
 	if( mul_type >= 2 ){
 		if( flg_arw ){
@@ -2430,7 +2566,7 @@ gold_t	get_price_wpn( item_t *item )
 		}
 	}
 
-	/**/
+	/* ()쥤䡼° */
 
 	if( item->dat.wpn.slayer != FACE_MJR_NULL ){
 		if( flg_arw ){
@@ -2440,7 +2576,17 @@ gold_t	get_price_wpn( item_t *item )
 		}
 	}
 
-	/**/
+	/* ࡦƥե */
+
+	for( i = 0; i < LOOP_MAX_1000; i++ ){
+		if( item->dat.wpn.randm_art[i].kind
+				== WPN_RANDM_ART_KIND_NULL ){
+			break;
+		}
+		price += PRICE_WPN_RANDM_ART;
+	}
+
+	/* ꤲʥա */
 
 	if( flg_dag ){
 		price = price / PRICE_DAGGER_DIV;
@@ -2459,11 +2605,16 @@ gold_t	get_price_wpn( item_t *item )
 	return price;
 }
 
-/**/
+/***************************************************************
+* ɶʤ׻
+* item_t *item : 
+* return : 
+***************************************************************/
 
 gold_t	get_price_armor( item_t *item )
 {
 	gold_t	price, def, crtcl, ac;
+	long	i;
 
 	if( item == NULL )
 		return( (gold_t)0 );
@@ -2474,7 +2625,7 @@ gold_t	get_price_armor( item_t *item )
 
 	price = 0;
 
-	/**/
+	/* ܤ */
 
 	def = item->tab.armor->def;
 	def *= item->tab.armor->def;
@@ -2503,7 +2654,7 @@ gold_t	get_price_armor( item_t *item )
 	price = price * PRICE_ARMOR_RATE / _100_PERCENT;
 	price += PRICE_ARMOR_BASE;
 
-	/**/
+	/* ٹǽ */
 
 	if( item->dat.armor.add_def < 0 )
 		return( (gold_t)0 );
@@ -2523,7 +2674,17 @@ gold_t	get_price_armor( item_t *item )
 	if( item->dat.armor.add_ac < 0 )
 		price += PRICE_ARMOR_ADD_AC_BASE;
 
-	/**/
+	/* ࡦƥե */
+
+	for( i = 0; i < LOOP_MAX_1000; i++ ){
+		if( item->dat.armor.randm_art[i].kind
+				== ARMOR_RANDM_ART_KIND_NULL ){
+			break;
+		}
+		price += PRICE_ARMOR_RANDM_ART;
+	}
+
+	/* ǡơ֥ */
 
 	price = price * item->tab.armor->rate_price / _100_PERCENT;
 	price += item->tab.armor->add_price;
@@ -2533,7 +2694,11 @@ gold_t	get_price_armor( item_t *item )
 	return price;
 }
 
-/**/
+/***************************************************************
+* ˡξʤ׻
+* item_t *item : 
+* return : 
+***************************************************************/
 
 gold_t	get_price_stick( item_t *item )
 {
@@ -2572,7 +2737,11 @@ gold_t	get_price_stick( item_t *item )
 	return price;
 }
 
-/**/
+/***************************************************************
+* ڴʤ׻
+* item_t *item : 
+* return : 
+***************************************************************/
 
 gold_t	get_price_inst( item_t *item )
 {
@@ -2598,7 +2767,11 @@ gold_t	get_price_inst( item_t *item )
 	return price;
 }
 
-/**/
+/***************************************************************
+* ʤ׻
+* item_t *item : 
+* return : 
+***************************************************************/
 
 gold_t	get_price_light( item_t *item )
 {
@@ -2621,7 +2794,11 @@ gold_t	get_price_light( item_t *item )
 	return price;
 }
 
-/**/
+/***************************************************************
+* ɲ׻
+* bool_t flg_short_stay : ٷƤ?
+* return : 
+***************************************************************/
 
 gold_t	get_price_inn( bool_t flg_short_stay )
 {
@@ -2637,7 +2814,11 @@ gold_t	get_price_inn( bool_t flg_short_stay )
 	return price;
 }
 
-/**/
+/***************************************************************
+* β׻
+* mbr_t *mbr : С
+* return : 
+***************************************************************/
 
 gold_t	get_price_temple_remove_curse( mbr_t *mbr )
 {
@@ -2653,7 +2834,11 @@ gold_t	get_price_temple_remove_curse( mbr_t *mbr )
 	return price;
 }
 
-/**/
+/***************************************************************
+* ξֲ׻
+* mbr_t *mbr : С
+* return : 
+***************************************************************/
 
 gold_t	get_price_temple_cure_status( mbr_t *mbr )
 {
@@ -2678,7 +2863,11 @@ gold_t	get_price_temple_cure_status( mbr_t *mbr )
 	return price;
 }
 
-/**/
+/***************************************************************
+* ׻
+* mbr_t *mbr : С
+* return : 
+***************************************************************/
 
 gold_t	get_price_temple_resurrection( mbr_t *mbr )
 {
@@ -2703,7 +2892,11 @@ gold_t	get_price_temple_resurrection( mbr_t *mbr )
 	return price;
 }
 
-/**/
+/***************************************************************
+* δդ׻
+* mbr_t *mbr : С
+* return : 
+***************************************************************/
 
 gold_t	get_price_temple_contribution( mbr_t *mbr )
 {
@@ -2720,7 +2913,11 @@ gold_t	get_price_temple_contribution( mbr_t *mbr )
 	return price;
 }
 
-/**/
+/***************************************************************
+* ŹδʸŹֹѴ
+* char face_mnr : Źδʸ
+* return : Źֹ
+***************************************************************/
 
 shop_n_t	get_shop_n( char face_mnr )
 {
@@ -2756,7 +2953,11 @@ shop_n_t	get_shop_n( char face_mnr )
 	return SHOP_N_INN;
 }
 
-/**/
+/***************************************************************
+* Źֹ椫ŹδʸѴ
+* shop_n_t n : Źֹ
+* return : Źδʸ
+***************************************************************/
 
 char	get_shop_mnr_face( shop_n_t n )
 {
@@ -2795,7 +2996,11 @@ char	get_shop_mnr_face( shop_n_t n )
 	return FACE_MNR_NULL;
 }
 
-/**/
+/***************************************************************
+* Źֹ椫Ź̾Ѵ
+* shop_n_t n : Źֹ
+* return : Ź̾
+***************************************************************/
 
 char	*get_shop_name( shop_n_t shop_n )
 {
@@ -2834,7 +3039,10 @@ char	*get_shop_name( shop_n_t shop_n )
 	return MSG_NULL;
 }
 
-/**/
+/***************************************************************
+* īƤǥޥåפ
+* long turn : 
+***************************************************************/
 
 void	set_map_sunshine( void )
 {
@@ -2877,7 +3085,10 @@ void	set_map_sunshine( void )
 	make_streetlamp();
 }
 
-/**/
+/***************************************************************
+* īƤΥå
+* long turn : 
+***************************************************************/
 
 void	chk_morning_glow( long turn )
 {
@@ -2916,7 +3127,10 @@ void	chk_morning_glow( long turn )
 	}
 }
 
-/**/
+/***************************************************************
+* ͼƤΥå
+* long turn : 
+***************************************************************/
 
 void	chk_evening_glow( long turn )
 {
@@ -2955,7 +3169,12 @@ void	chk_evening_glow( long turn )
 	}
 }
 
-/**/
+/***************************************************************
+* īͼƤٹ֤
+* long turn : 
+* bool_t flg_morning : īƤ?
+* return : īͼƤٹ
+***************************************************************/
 
 long	get_glow_n( long turn, bool_t flg_morning )
 {
@@ -2979,7 +3198,12 @@ long	get_glow_n( long turn, bool_t flg_morning )
 	return 4;
 }
 
-/**/
+/***************************************************************
+* īͼƤ
+* long dx : X īƤа
+* long dy : Y īƤа
+* bool_t flg_morning : īƤ?
+***************************************************************/
 
 void	set_map_glow( long dx, long dy, bool_t flg_morning )
 {
@@ -3014,7 +3238,10 @@ void	set_map_glow( long dx, long dy, bool_t flg_morning )
 	redraw_map();
 }
 
-/**/
+/***************************************************************
+* αɽ
+* shop_n_t n : Źֹ
+***************************************************************/
 
 void	hear_rumor( shop_n_t shop_n )
 {
@@ -3067,7 +3294,10 @@ void	hear_rumor( shop_n_t shop_n )
 			MSG( rumor_tab[tab_n].n_msg_male ) );
 }
 
-/**/
+/***************************************************************
+* 椫Ĵ٤
+* return : 椫?
+***************************************************************/
 
 bool_t	chk_discount( void )
 {
@@ -3079,7 +3309,10 @@ bool_t	chk_discount( void )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* Ĵ٤
+* return : ?
+***************************************************************/
 
 bool_t	chk_discount_day( void )
 {
@@ -3102,7 +3335,10 @@ bool_t	chk_discount_day( void )
 	return FALSE;
 }
 
-/**/
+/***************************************************************
+* ΥĴ٤
+* return : Υ?
+***************************************************************/
 
 bool_t	chk_discount_turn()
 {
@@ -3125,7 +3361,10 @@ bool_t	chk_discount_turn()
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ǱĶȻ椫Ĵ٤
+* return : ĶȻ椫?
+***************************************************************/
 
 bool_t	chk_discount_open()
 {
@@ -3142,7 +3381,11 @@ bool_t	chk_discount_open()
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ŹΥɥĴ٤
+* door_t *dr : ɥ
+* return : Ź?
+***************************************************************/
 
 bool_t	chk_discount_door( door_t *dr )
 {
@@ -3155,7 +3398,11 @@ bool_t	chk_discount_door( door_t *dr )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* 饯椫Ĵ٤
+* chr_t *chr : 饯
+* return : 椫?
+***************************************************************/
 
 bool_t	chk_queue_chr( chr_t *chr )
 {
@@ -3168,7 +3415,11 @@ bool_t	chk_queue_chr( chr_t *chr )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* 饯˰󤻤뤫Ĵ٤
+* chr_t *chr : 饯
+* return : 󤻤뤫?
+***************************************************************/
 
 bool_t	chk_discount_mark( chr_t *chr )
 {
@@ -3198,9 +3449,11 @@ bool_t	chk_discount_mark( chr_t *chr )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* Τ
+***************************************************************/
 
-void	set_discount()
+void	set_discount( void )
 {
 	door_t	*dr;
 
@@ -3215,7 +3468,9 @@ void	set_discount()
 	set_discount_queue( dr );
 }
 
-/**/
+/***************************************************************
+* Τ
+***************************************************************/
 
 void	clr_discount( void )
 {
@@ -3224,14 +3479,20 @@ void	clr_discount( void )
 	g_discount_queue.flg_sold_out = TRUE;
 }
 
-/**/
+/***************************************************************
+* ڤ
+***************************************************************/
 
 void	set_discount_sold_out()
 {
 	g_discount_queue.flg_sold_out = TRUE;
 }
 
-/**/
+/***************************************************************
+* ΰ֤
+* door_t *dr : ɥ
+* return : Ǥ?
+***************************************************************/
 
 bool_t	set_discount_queue( door_t *dr )
 {
@@ -3317,14 +3578,21 @@ bool_t	set_discount_queue( door_t *dr )
 	return ret;
 }
 
-/**/
+/***************************************************************
+* Υǡ֤
+* return : Υǡ
+***************************************************************/
 
 discount_queue_t	*get_discount_queue( void )
 {
 	return &g_discount_queue;
 }
 
-/**/
+/***************************************************************
+* οͿ֤
+* chr_t *chr : 饯
+* return : οͿ
+***************************************************************/
 
 long	get_discount_queue_n( chr_t *chr )
 {
@@ -3334,7 +3602,11 @@ long	get_discount_queue_n( chr_t *chr )
 	return g_discount_queue.n;
 }
 
-/**/
+/***************************************************************
+* κĹͿ֤
+* chr_t *chr : 饯
+* return : κĹͿ
+***************************************************************/
 
 long	get_discount_queue_max_n( chr_t *chr )
 {
@@ -3344,7 +3616,9 @@ long	get_discount_queue_max_n( chr_t *chr )
 		return DISCOUNT_QUEUE_MAX_N - MBR_MAX_N;
 }
 
-/**/
+/***************************************************************
+* ʤ뤫Ĵ٤
+***************************************************************/
 
 void	chk_discount_queue( void )
 {
@@ -3362,7 +3636,10 @@ void	chk_discount_queue( void )
 	}
 }
 
-/**/
+/***************************************************************
+* 饯᤿Ĵ٤
+* chr_t *chr : 饯
+***************************************************************/
 
 void	chk_clr_chr_discount_queue( chr_t *chr )
 {
@@ -3378,7 +3655,10 @@ void	chk_clr_chr_discount_queue( chr_t *chr )
 	clr_chr_trgt_act( chr, FALSE );
 }
 
-/**/
+/***************************************************************
+* Υ饯ŹäĴ٤
+* chr_t *chr : 饯
+***************************************************************/
 
 void	chk_enter_discount_shop( chr_t *chr )
 {
@@ -3397,7 +3677,10 @@ void	chk_enter_discount_shop( chr_t *chr )
 	mark_door( chr, g_discount_queue.door, DIST_NEAR );
 }
 
-/**/
+/***************************************************************
+* 饯ˤʤ
+* chr_t *chr : 饯
+***************************************************************/
 
 void	inc_discount_queue( chr_t *chr )
 {
@@ -3413,7 +3696,10 @@ void	inc_discount_queue( chr_t *chr )
 		print_msg( FLG_NULL, MSG_INC_DISCOUNT_QUEUE, chr->name );
 }
 
-/**/
+/***************************************************************
+* ʤ
+* long n : ν
+***************************************************************/
 
 void	dec_discount_queue( long n )
 {
@@ -3436,7 +3722,10 @@ void	dec_discount_queue( long n )
 		g_discount_queue.n = 0;
 }
 
-/**/
+/***************************************************************
+* Źֹ椫ŹΥɥѴ
+* shop_n_t n : Źֹ
+***************************************************************/
 
 door_t	*get_shop_door( shop_n_t n )
 {
@@ -3456,28 +3745,40 @@ door_t	*get_shop_door( shop_n_t n )
 	return NULL;
 }
 
-/**/
+/***************************************************************
+* ѥοơ֥֤
+* return : ѥοơ֥
+***************************************************************/
 
 town_ptn_col_tab_t	*get_town_ptn_col_tab( void )
 {
 	return town_ptn_col_tab;
 }
 
-/**/
+/***************************************************************
+* ѥοơ֥κ֤
+* return : ѥοơ֥κ
+***************************************************************/
 
 long	get_town_ptn_col_tab_max_n( void )
 {
 	return town_ptn_col_tab_max_n;
 }
 
-/**/
+/***************************************************************
+* ڥåȡåפΥڥåȤΥꥹȤ֤
+* return : ڥåȤΥꥹ
+***************************************************************/
 
 art_ls_pet_shop_t	*get_art_ls_pet_shop( void )
 {
 	return art_ls_pet_shop;
 }
 
-/**/
+/***************************************************************
+* ǡ򥻡
+* return : 顼̵ä
+***************************************************************/
 
 bool_t	save_town( void )
 {
@@ -3488,5 +3789,3 @@ bool_t	save_town( void )
 
 	return TRUE;
 }
-
-/**/
