@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: ver.h,v 1.54 2008/04/03 11:48:18 bowkenken Exp $
+* $Id: ver.h,v 1.60 2009/06/23 12:56:26 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	VER_H
@@ -37,25 +37,35 @@
 #define	STR_VER_GAME	VERSION
 
 #define	STR_SINCE	"1993"
-#define	STR_LATEST	"2008"
-#define	STR_AUTHOR	"YOSHIMURA Tomohiko"
+#define	STR_LATEST	"2009"
+#define	STR_AUTHOR	"YOSHIMURA, Tomohiko"
 
 #define	STR_WEB	"http://lnl.sourceforge.jp/"
 #define	STR_E_MAIL	"bowkenken@users.sourceforge.jp"
 
 #define	STR_TITLE_1	"Created by"
-#define	STR_HANDLE_1	"BowKenKen"
+#define	STR_HANDLE_1	"bowkenken"
 
 #define	STR_TITLE_2	"Graphic Design"
 #define	STR_HANDLE_2	"[RPG DOT], Whitecat, REFMAP"
 
 #define	STR_TITLE_3	" "
-#define	STR_HANDLE_3	"kokusi(yujyu) hiyo and URARA"
+#define	STR_HANDLE_3	"kokusi(yujyu), hiyo URARA"
+
+#define	STR_TITLE_4	" "
+#define	STR_HANDLE_4	"and naramura"
+
+#define	STR_TITLE_5	"Photograph"
+#define	STR_HANDLE_5	"Yoshinori Kamimura"
+
+#define	STR_TITLE_6	"Music Production"
+#define	STR_HANDLE_6	"Presence of Music"
 
 #define	STR_TITLE_THANKS	"Special Thanks"
 #define	STR_HANDLE_THANKS	"t-oikawa, TeaMiKL, nnn and you"
 
 #define	STR_FMT_COPYRIGHT	\
+		"\n" \
 		"--------------------------------" \
 		"--------------------------------\n" \
 		"%s : version %s  \n" \
@@ -70,6 +80,9 @@
 		"%20s  %-42s\n" \
 		"%20s  %-42s\n" \
 		"%20s  %-42s\n" \
+		"%20s  %-42s\n" \
+		"%20s  %-42s\n" \
+		"%20s  %-42s\n" \
 		"--------------------------------" \
 		"--------------------------------\n" \
 		""
@@ -82,6 +95,9 @@
 		STR_TITLE_1, STR_HANDLE_1, \
 		STR_TITLE_2, STR_HANDLE_2, \
 		STR_TITLE_3, STR_HANDLE_3, \
+		STR_TITLE_4, STR_HANDLE_4, \
+		STR_TITLE_5, STR_HANDLE_5, \
+		STR_TITLE_6, STR_HANDLE_6, \
 		STR_TITLE_THANKS, STR_HANDLE_THANKS
 
 #endif	/* VER_H */
